(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    552455,      11157]
NotebookOptionsPosition[    541394,      11016]
NotebookOutlinePosition[    541988,      11038]
CellTagsIndexPosition[    541945,      11035]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook provides step-by-step derivation of the Method of \
Manufactured Solutions (MMS) for an extremely high-shear prescribed \
deformation.\nThis is the working notebook that was ultimately summarized in \
Appendix 1 of reference [1].\n\nThis notebook includes commands to generate \
the following pictures of a special deformation:\n",
 Cell[BoxData[
  GraphicsBox[
   TagBox[RasterBox[CompressedData["
1:eJzsnQeYFNXShvuq95p/rxEDVzFnRTGggIoKKggighFEUIKARBEDWRREQVEJ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     "], {{0, 334}, {334, 0}}, {0, 255},
     ColorFunction->RGBColor],
    BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
    Selectable->False],
   DefaultBaseStyle->"ImageGraphics",
   ImageSize->Automatic,
   ImageSizeRaw->{334, 334},
   PlotRange->{{0, 334}, {0, 334}}]], "Input",ExpressionUUID->
  "0fcadb6d-ca1d-4669-a289-2855706b5c33"],
 Cell[BoxData[
  GraphicsBox[
   TagBox[RasterBox[CompressedData["
1:eJztfV/IbddVb9a9L/p2+2bfzJvnzT715vGDQDnUPsR6AwFBKk31IFZSbwh5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     "], {{0, 333}, {331, 0}}, {0, 255},
     ColorFunction->RGBColor],
    BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
    Selectable->False],
   DefaultBaseStyle->"ImageGraphics",
   ImageSize->Automatic,
   ImageSizeRaw->{331, 333},
   PlotRange->{{0, 331}, {0, 333}}]], "Input",ExpressionUUID->
  "5394dd0a-84f7-4395-9d6e-d20394106b82"],
 Cell[BoxData[
  GraphicsBox[
   TagBox[RasterBox[CompressedData["
1:eJzsfQd8HNWd/08u1LS75LjkcvnnkrtUQkghgeS45NLLHXcpJOFIJU8YHGoI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     "], {{0, 309}, {308, 0}}, {0, 255},
     ColorFunction->RGBColor],
    BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
    Selectable->False],
   DefaultBaseStyle->"ImageGraphics",
   ImageSize->Automatic,
   ImageSizeRaw->{308, 309},
   PlotRange->{{0, 308}, {0, 309}}]], "Input",ExpressionUUID->
  "aaeda287-23ef-4247-9f83-6a938aead72e"],
 Cell[BoxData[
  GraphicsBox[
   TagBox[RasterBox[CompressedData["
1:eJzsnQdcE8v2+MeOHXvvvWLvvWLHjr0EEQQRERUVEb220BEVEQuCARFFBBGR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     "], {{0, 307}, {307, 0}}, {0, 255},
     ColorFunction->RGBColor],
    BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
    Selectable->False],
   DefaultBaseStyle->"ImageGraphics",
   ImageSize->Automatic,
   ImageSizeRaw->{307, 307},
   PlotRange->{{0, 307}, {0, 307}}]], "Input",ExpressionUUID->
  "bfbdf6b2-d88e-4132-9eff-8dd2fa4a45be"],
 "\nAs seen, this deformation is designed so that all points in the ENTIRE \
domain undergo a state of simple shear along with superimposed rotation. As \
such, this motion is an excellent choice to test large-deformation numerical \
codes for robustness and and accurate in their solution to the equations of \
motion as well as testing the constitutive model (and/or its implementation) \
for proper behavior under extraordinarily large shears (like what might be \
expected near a penetrator) and under superimposed rotation (as required from \
material frame indifference yet shockingly often missed in constitutive model \
testing). \n\nThe basic idea behind MMS is to dream up an interesting \
deformation like the one in this notebook, from which you can then derive \
corresponding kinematics quantities, such as\n\n\tdisplacement\n\tvelocity\n\t\
accelerations\n\tdeformation gradient tensor\n\tstrain and strain rate\n\t\
Jacobian of the deformation (from which evolving mass density is then known)\n\
\nKnowing these known at all locations, and also knowing your choice of an \
elastic constitutive model, you should have enough information to determine \
the corresponding stress tensors required to induce the motion. In this \
notebook, we avoid introducing any particular constitutive model until the \
very last step. This way, the bulk of the work can be applied to any \
arbitrary choice of isotropic elastic constitutive model (or any inelastic \
one if unloading is disallowed). Because this notebook designs a very special \
material motion in which all points are undergoing a state of varying degrees \
of simple shear with varying degrees of superimposed rotation, we can write \
the stress state generically as a function of the shear strain at any given \
location. The detail of the function would come from considering your choice \
of constitutive model in the special case of simple shear without \
superimposed rotation, and (as further clarified below) it is therefore \
treated as a known generic function. Simple shear is simple enough that this \
function can be found analytically for most material models, but even that \
isn\[CloseCurlyQuote]t needed -- if you can\[CloseCurlyQuote]t get it \
analytically, then you can generate it numerically and represent it via a \
lookup table (although such an approach has the disadvantage of not properly \
testing your constitutive model for things like the host code failing to send \
the correct strain definition as input). \n\nOnce the local material motion \
is applied along with the elastic constitutive model to find the local stress \
at each location in the domain of the manufactured material motion, the next \
step is to then evaluate the divergence of stress. Recalling that the \
acceleration was a previously computed kinematic property of the MMS, and now \
knowing the stress divergence, the corresponding body force may be determined \
from the equations of motion! That\[CloseCurlyQuote]s what this notebook \
does. \n\nAn MMS verification test is performed in a host (such as an FEM \
code) as follows:\n\t1. use the analytically determined initial particle \
velocities (from this notebook) to initialize the state \n\t(the MMS in this \
notebook is designed to have a zero initial velocity, alleviating the burden \
of this step)\n\t2. use the analytically determined body force (from this \
notebook) to drive material motion\n\t3. use the analytically determined \
surface tractions (from this notebook) as part of what drives the material \
motion \n\t(the MMS in this notebook is designed to have surface tractions \
all zero, alleviating the burden of this step)\n\t4. Run the host code to \
extract displacement as a function of time and position\n\t5. Compare the \
computed displacement to the MMS analytical displacement (from this notebook) \
to evaluate \n\t\tsimulation errors, which (after resolving constitutive \
model and algorithm bugs that \n\t\tare often revealed by doing an MMS \
simulation in the first place) are ultimately the result of \n\t\tmesh \
refinement errors.\n\t6. Redo the computations on increasingly refined meshes \
to obtain a rational assessment \n\t\tof the solution algorithm\
\[CloseCurlyQuote]s rate of convergence in non-trivial heterogenous material \
motion.\n\nNote: because this particular MMS will involve motion inside a \
ring such that material strain is identically zero at the boundary of that \
ring, a host code has two options:\n\n\n\tOption A. Run a simulation of just \
the ring itself using zero traction at the boundary:\n\t\t\t\t ",
 Cell[BoxData[
  GraphicsBox[
   TagBox[RasterBox[CompressedData["
1:eJzsnQeYFNXShlvv9TfrNeecs5gVTKiACAiIiqiogAKiIBjJKIiIgOSo5IyS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     "], {{0, 373}, {378, 0}}, {0, 255},
     ColorFunction->RGBColor],
    BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
    Selectable->False],
   DefaultBaseStyle->"ImageGraphics",
   ImageSize->{220., Automatic},
   ImageSizeRaw->{378, 373},
   PlotRange->{{0, 378}, {0, 373}}]], "Input",ExpressionUUID->
  "37cb1494-9a5b-4724-836a-65d402a032d0"],
 "\n\t\t\t\t \n\t\t\t\t \n\tOption B. Run a simulation of a domain in which \
there is material both inside and outside the ring:\n\t\t\t\t",
 Cell[BoxData[
  GraphicsBox[
   TagBox[RasterBox[CompressedData["
1:eJztfV/IbddVb9e9L9e3mzfz1vOW82bfbh4UPlByD/iSVgvnRTl6WzkEek29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     "], {{0, 329}, {328, 0}}, {0, 255},
     ColorFunction->RGBColor],
    BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
    Selectable->False],
   DefaultBaseStyle->"ImageGraphics",
   ImageSize->{230., Automatic},
   ImageSizeRaw->{328, 329},
   PlotRange->{{0, 328}, {0, 329}}]], "Input",ExpressionUUID->
  "00652615-a63d-4be9-bf45-ee5b24b7009f"],
 "\n\t\tThis is a convenient option for Eulerian codes that always run all \
simulations on rectangular domains.\n\t\tThis option is also a nice way to \
clearly see simulation errors, because any grid motion \n\t\toutside the ring \
is a visible indicator of error -- the exact solution has no motion \
whatsoever!\n\n\n\n\n\n\nNow let\[CloseCurlyQuote]s get started working out \
the kinematics for the \[OpenCurlyDoubleQuote]Generalized Vortex\
\[CloseCurlyDoubleQuote] rotation of material points around the ring \
illustrated above...\n\n\nFor this MMS, we consider a mapping from initial \
position ",
 Cell[BoxData[
  FormBox[
   UnderscriptBox["X", "~"], TraditionalForm]],ExpressionUUID->
  "00f318b1-50eb-4249-8ae3-adcb2bae1495"],
 " to current position ",
 Cell[BoxData[
  FormBox[
   UnderscriptBox["x", "~"], TraditionalForm]],ExpressionUUID->
  "7156006d-a391-45b8-9917-39406eeb5424"],
 " given by\n\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderscriptBox["x", "~"], "=", 
    RowBox[{
     UnderscriptBox[
      UnderscriptBox["Q", "~"], "~"], ".", 
     UnderscriptBox["X", "~"]}]}], TraditionalForm]],ExpressionUUID->
  "5f2c1e9c-a065-4fd5-b4f2-4c0522b1bfc8"],
 "\nwhere ",
 Cell[BoxData[
  FormBox[
   UnderscriptBox[
    UnderscriptBox["Q", "~"], "~"], TraditionalForm]],ExpressionUUID->
  "fac9647f-f3f8-4b6a-a8b2-e41352ca381e"],
 " is an orthogonal tensor with components\n\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"[", 
     UnderscriptBox[
      UnderscriptBox["Q", "~"], "~"], "]"}], "=", 
    RowBox[{"(", GridBox[{
       {
        RowBox[{"Cos", "[", "\[Alpha]", "]"}], 
        RowBox[{"-", 
         RowBox[{"Sin", "[", "\[Alpha]", "]"}]}], "0"},
       {
        RowBox[{"Sin", "[", "\[Alpha]", "]"}], 
        RowBox[{"Cos", "[", "\[Alpha]", "]"}], "0"},
       {"0", "0", "1"}
      }], ")"}]}], TraditionalForm]],ExpressionUUID->
  "ec9b7335-1a23-4efb-ac1a-ed6e73f70f7f"],
 "\nThis notebook allows the rotation angle to vary with radial coordinate R, \
but not with angular coordinate.\nThe rotation angle is also allowed to vary \
with time. Specifically,\n\t\[Alpha][R,t]=g[t]h[R]\nwhere the functions g and \
h are given (specific examples are selected below for the visualizations, but \
they are kept generic for now in order to give as much generality as possible \
to the MMS formulas while still keeping them easy to work with).  The \
function h[R] controls the shape of the bump in motion, illustrated by the \
black line in the first image above. The g[t] function controls the \
magnitude. \n\nIf the g[t] function has the property that g[0] = 0, then it \
follows that there is no deformation in the initial state. If it has a zero \
slope at time zero so that g\[CloseCurlyQuote][0] = 0, then the material has \
no initial velocity, thus making it easier to test a code by not requiring it \
to set up a complicated initial velocity field.\n\nIf the h[R] function has \
the property that its value and slope are both zero at the inner and outer \
radii of the ring, this MMS will entail zero traction at the ring boundary, \
thus simplifying the testing of the code. The h[R] function can, of course, \
later be changed to have a nonzero slope at the boundaries to test the code\
\[CloseCurlyQuote]s ability to correctly impose shear tractions. In that \
case, the appropriate shear traction would be inferred from the constitutive \
model in simple shear (beyond scope of this notebook).\n\nKeeping the \
\[Alpha][R,t] function generic, the goal of this notebook is to find that \
body force field corresponding to this motion.\n\nNote that\n\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox[
     RowBox[{"d", 
      UnderscriptBox[
       UnderscriptBox["Q", "~"], "~"]}], "d\[Alpha]"], "=", 
    RowBox[{
     UnderscriptBox[
      UnderscriptBox["A", "~"], "~"], ".", " ", 
     UnderscriptBox[
      UnderscriptBox["Q", "~"], "~"]}]}], TraditionalForm]],ExpressionUUID->
  "da711cce-0089-4a04-aaa3-0024d5c37a5b"],
 ", \nwhere ",
 Cell[BoxData[
  FormBox[
   UnderscriptBox[
    UnderscriptBox["A", "~"], "~"], TraditionalForm]],ExpressionUUID->
  "3deb14b2-e5b9-4ccb-b8ad-052b8326e33d"],
 " is the axial tensor associated with the axis of rotation. Namely,\n\t",
 Cell[BoxData[
  FormBox[
   UnderscriptBox[
    UnderscriptBox["A", "~"], "~"], TraditionalForm]],ExpressionUUID->
  "db76c4de-1ca6-4982-bdf2-bfedba696da9"],
 "=",
 Cell[BoxData[
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {"0", 
       RowBox[{"-", "1"}], "0"},
      {"1", "0", "0"},
      {"0", "0", "0"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]]],
  CellChangeTimes->{
   3.4852188837080145`*^9, {3.4852189406500144`*^9, 3.4852190038420143`*^9}, 
    3.4852192716430144`*^9},ExpressionUUID->
  "289fd751-382b-405b-a697-a6fa4590d9a6"],
 "\n\tThis is simply a counter-clockwise rotation of 90\[Degree] in the plane \
of motion.\n\t\nThus, for any scalar ",
 StyleBox["s",
  FontSlant->"Italic"],
 ", \n",
 Cell[BoxData[
  FormBox[
   RowBox[{"\t", 
    RowBox[{
     FractionBox[
      RowBox[{"\[PartialD]", 
       UnderscriptBox[
        UnderscriptBox["Q", "~"], "~"]}], 
      RowBox[{"\[PartialD]", " ", "s"}]], "=", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"d", 
         UnderscriptBox[
          UnderscriptBox["Q", "~"], "~"]}], 
        RowBox[{"d", " ", "\[Alpha]"}]], 
       FractionBox[
        RowBox[{"\[PartialD]", " ", "\[Alpha]"}], 
        RowBox[{"\[PartialD]", " ", "s"}]]}], "=", 
      RowBox[{
       RowBox[{
        UnderscriptBox[
         UnderscriptBox["A", "~"], "~"], ".", " ", 
        UnderscriptBox[
         UnderscriptBox["Q", "~"], "~"]}], 
       FractionBox[
        RowBox[{"\[PartialD]", " ", "\[Alpha]"}], 
        RowBox[{"\[PartialD]", " ", "s"}]]}]}]}]}], TraditionalForm]],
  ExpressionUUID->"e5afea1c-3b1f-435b-9850-8f77951c2d63"],
 "\nThis lemma will be used in upcoming formulas whenever any derivative of \
the ",
 Cell[BoxData[
  FormBox[
   UnderscriptBox["Q", "\[TildeTilde]"], TraditionalForm]],ExpressionUUID->
  "d676d464-b036-4c80-b6e1-2eb3a0d78640"],
 " tensor is needed.\n\nLetting ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox[
     UnderscriptBox[
      StyleBox["e",
       FontSlant->"Plain"], "~"],
     FontWeight->"Bold",
     FontSlant->"Italic"], "r"], TraditionalForm]],ExpressionUUID->
  "2dabcad1-7219-4c02-80be-c43e28cc491f"],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     StyleBox[
      UnderscriptBox[
       StyleBox["e",
        FontSlant->"Plain"], "~"],
      FontWeight->"Bold",
      FontSlant->"Italic"], "\[Theta]"], ",", " ", 
    RowBox[{"and", "  ", 
     SubscriptBox[
      StyleBox[
       UnderscriptBox[
        StyleBox["e",
         FontSlant->"Plain"], "~"],
       FontWeight->"Bold",
       FontSlant->"Italic"], "z"]}]}], TraditionalForm]],ExpressionUUID->
  "a10a2295-4f98-4335-b45f-f5450cd0bd4b"],
 " denote the spatial cylindrical basis vectors, notice (for future \
reference):\n\t",
 Cell[BoxData[
  FormBox[
   UnderscriptBox[
    UnderscriptBox["A", "~"], "~"], TraditionalForm]],ExpressionUUID->
  "fadf79b1-8ce4-4352-9208-ae9fe1775849"],
 " \[CenterDot] ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox[
     UnderscriptBox[
      StyleBox["e",
       FontSlant->"Plain"], "~"],
     FontWeight->"Bold",
     FontSlant->"Italic"], "r"], TraditionalForm]],ExpressionUUID->
  "22c9faa0-c0d9-4dcd-a85d-f0ca9956165b"],
 "=",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox[
     UnderscriptBox[
      StyleBox["e",
       FontSlant->"Plain"], "~"],
     FontWeight->"Bold",
     FontSlant->"Italic"], "\[Theta]"], TraditionalForm]],ExpressionUUID->
  "f1da9ee5-64a6-4cca-b2b3-ad1da182d534"],
 "\n\t",
 Cell[BoxData[
  FormBox[
   UnderscriptBox[
    UnderscriptBox["A", "~"], "~"], TraditionalForm]],ExpressionUUID->
  "9751df52-493a-480a-bc83-e207adfd8632"],
 " \[CenterDot] ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox[
     UnderscriptBox[
      StyleBox["e",
       FontSlant->"Plain"], "~"],
     FontWeight->"Bold",
     FontSlant->"Italic"], "\[Theta]"], TraditionalForm]],ExpressionUUID->
  "bed77787-1ca5-4a3a-9e09-ede1649f4a59"],
 "=",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox["-",
     FontWeight->"Bold",
     FontSlant->"Italic"], 
    SubscriptBox[
     StyleBox[
      UnderscriptBox[
       StyleBox["e",
        FontSlant->"Plain"], "~"],
      FontWeight->"Bold",
      FontSlant->"Italic"], "r"]}], TraditionalForm]],ExpressionUUID->
  "d98e7cd4-4aad-423b-83c0-934e90746d04"],
 "\n\t",
 Cell[BoxData[
  FormBox[
   UnderscriptBox[
    UnderscriptBox["A", "~"], "~"], TraditionalForm]],ExpressionUUID->
  "6da817fe-3c7d-48f6-9f0b-72affdba5ecd"],
 " \[CenterDot] ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox[
     UnderscriptBox[
      StyleBox["e",
       FontSlant->"Plain"], "~"],
     FontWeight->"Bold",
     FontSlant->"Italic"], "z"], TraditionalForm]],ExpressionUUID->
  "13d47acd-3c04-4233-8745-832be3b0dc36"],
 "=",
 Cell[BoxData[
  FormBox[
   StyleBox[
    UnderscriptBox[
     StyleBox["0",
      FontSlant->"Plain"], "~"],
    FontWeight->"Bold",
    FontSlant->"Italic"], TraditionalForm]],ExpressionUUID->
  "d6ed6a6d-a8ad-40a7-82ad-c2024c4bd34a"]
}], "Text",
 CellChangeTimes->{{3.485217874384014*^9, 3.4852180819870143`*^9}, {
   3.485218590752014*^9, 3.4852186013870144`*^9}, {3.4852277838790145`*^9, 
   3.4852278266350145`*^9}, {3.4852278684510145`*^9, 
   3.4852279555140142`*^9}, {3.4852279919870143`*^9, 
   3.4852280654340143`*^9}, {3.4852281641140146`*^9, 
   3.4852282036550145`*^9}, {3.4852283977510147`*^9, 
   3.4852283988420143`*^9}, {3.4852335129850144`*^9, 
   3.4852335389070144`*^9}, {3.7507767436054106`*^9, 
   3.7507773296336327`*^9}, {3.750777647856762*^9, 3.75077767305484*^9}, {
   3.7507777078217225`*^9, 3.7507777221692142`*^9}, 3.750777757124055*^9, {
   3.750777813540304*^9, 3.7507779715532746`*^9}, {3.750778012409253*^9, 
   3.7507788221148224`*^9}, {3.7507788741712074`*^9, 3.75077921177283*^9}, {
   3.7507792777407646`*^9, 3.750779369220558*^9}, {3.750779479567336*^9, 
   3.7507795545543947`*^9}, {3.7507795988572493`*^9, 
   3.7507795996180067`*^9}, {3.750779722501775*^9, 3.750779936752585*^9}, {
   3.750779969096242*^9, 3.750779976558877*^9}, {3.7507800091204805`*^9, 
   3.7507800091204805`*^9}, {3.7507800558785543`*^9, 3.750780056982202*^9}, {
   3.7507846929300556`*^9, 3.750784764398343*^9}, {3.750784801173607*^9, 
   3.7507849007949343`*^9}, {3.750784936170639*^9, 3.7507851674668922`*^9}, {
   3.7507852004343667`*^9, 3.7507854241153307`*^9}, {3.750785457083805*^9, 
   3.750785457915539*^9}, {3.7507855089592648`*^9, 3.750785661451671*^9}, 
   3.750785698169952*^9},ExpressionUUID->"cb8ae8be-6fb7-4b4d-b82c-\
0a0e388d6742"],

Cell[CellGroupData[{

Cell["Velocity and acceleration", "Section",
 CellChangeTimes->{{3.4852278301970143`*^9, 
  3.485227837148014*^9}},ExpressionUUID->"d94ca194-aa74-49b8-b2e6-\
9a441ffd3418"],

Cell[TextData[{
 "Recall that\n",
 "\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderscriptBox["x", "~"], "=", 
    RowBox[{
     UnderscriptBox[
      UnderscriptBox["Q", "~"], "~"], ".", 
     UnderscriptBox["X", "~"]}]}], TraditionalForm]],ExpressionUUID->
  "b24b15fe-8cc0-42b1-8da3-f41d5905ba4c"]
}], "Text",
 CellChangeTimes->{{3.4852646789520864`*^9, 
  3.485264681838092*^9}},ExpressionUUID->"cad12c40-0a34-452c-b18e-\
649329fac7cf"],

Cell[TextData[{
 "The velocity is the time derivative holding ",
 Cell[BoxData[
  FormBox[
   UnderscriptBox["X", "~"], TraditionalForm]],ExpressionUUID->
  "8892d62a-55c4-43fb-84db-b2088a478388"],
 " constant:\n\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderscriptBox["v", "~"], "=", 
    RowBox[{
     SubscriptBox[
      RowBox[{"(", 
       FractionBox[
        RowBox[{"\[PartialD]", 
         UnderscriptBox["x", "~"]}], 
        RowBox[{"\[PartialD]", " ", "t"}]], ")"}], 
      UnderscriptBox["X", "~"]], "=", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"\[PartialD]", 
         UnderscriptBox[
          UnderscriptBox["Q", "~"], "~"]}], 
        RowBox[{"\[PartialD]", " ", "t"}]], ".", 
       UnderscriptBox["X", "~"]}], "=", 
      RowBox[{
       RowBox[{
        RowBox[{
         UnderscriptBox[
          UnderscriptBox["A", "~"], "~"], ".", " ", 
         UnderscriptBox[
          UnderscriptBox["Q", "~"], "~"]}], 
        RowBox[{
         FractionBox[
          RowBox[{"\[PartialD]", " ", "\[Alpha]"}], 
          RowBox[{"\[PartialD]", " ", "t"}]], ".", 
         UnderscriptBox["X", "~"]}]}], "=", 
       RowBox[{
        RowBox[{
         RowBox[{"g", "'"}], "[", "t", "]"}], 
        RowBox[{"h", "[", "R", "]"}], 
        RowBox[{
         UnderscriptBox[
          UnderscriptBox["A", "~"], "~"], ".", " ", 
         UnderscriptBox[
          UnderscriptBox["Q", "~"], "~"], ".", 
         UnderscriptBox["X", "~"]}]}]}]}]}]}], TraditionalForm]],
  ExpressionUUID->"34d201a0-cb63-4dae-8a48-671251d0c850"],
 "\nor \n\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderscriptBox["v", "~"], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"g", "'"}], "[", "t", "]"}], 
     RowBox[{"h", "[", "R", "]"}], 
     RowBox[{
      UnderscriptBox[
       UnderscriptBox["A", "~"], "~"], ".", " ", 
      UnderscriptBox["x", "~"]}]}]}], TraditionalForm]],ExpressionUUID->
  "a760152f-ae1a-4dde-9a4d-f648a1578190"],
 "\n\nThe acceleration is\n\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderscriptBox["a", "~"], "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"g", "''"}], "[", "t", "]"}], 
      RowBox[{"h", "[", "R", "]"}], 
      RowBox[{
       UnderscriptBox[
        UnderscriptBox["A", "~"], "~"], ".", " ", 
       UnderscriptBox["x", "~"]}]}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{"g", "'"}], "[", "t", "]"}], 
      RowBox[{"h", "[", "R", "]"}], 
      RowBox[{
       UnderscriptBox[
        UnderscriptBox["A", "~"], "~"], ".", " ", 
       UnderscriptBox["v", "~"]}]}]}]}], TraditionalForm]],ExpressionUUID->
  "e6fe8046-0f21-4539-9927-29e0738d272f"],
 "\nor\n\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderscriptBox["a", "~"], "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"g", "''"}], "[", "t", "]"}], 
      RowBox[{"h", "[", "R", "]"}], 
      RowBox[{
       UnderscriptBox[
        UnderscriptBox["A", "~"], "~"], ".", " ", 
       UnderscriptBox["x", "~"]}]}], "-", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"g", "'"}], "[", "t", "]"}], 
         RowBox[{"h", "[", "R", "]"}]}], " ", ")"}], "2"], " ", 
      UnderscriptBox["x", "~"]}]}]}], TraditionalForm]],ExpressionUUID->
  "54c5f0b7-b6c7-4d27-9dc0-c3d48fa9f37f"],
 "\nThe spatial components of acceleration are\n\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "r"], "="}], TraditionalForm]],ExpressionUUID->
  "1d8b3325-4d94-46ba-ace0-2e62e27e8558"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"g", "''"}], "[", "t", "]"}], 
     RowBox[{"h", "[", "R", "]"}], 
     RowBox[{
      UnderscriptBox[
       UnderscriptBox["A", "~"], "~"], ".", " ", 
      UnderscriptBox["x", "~"]}]}], "-", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"g", "'"}], "[", "t", "]"}], 
        RowBox[{"h", "[", "R", "]"}]}], " ", ")"}], "2"], " ", 
     UnderscriptBox["x", "~"]}]}], TraditionalForm]],ExpressionUUID->
  "4b199c4a-aa6f-4a58-bcf3-5ce4c4b2ed1d"],
 "\nNoting that  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderscriptBox["x", "~"], "=", 
    RowBox[{
     RowBox[{"r", " ", 
      SubscriptBox[
       StyleBox[
        UnderscriptBox[
         StyleBox["e",
          FontSlant->"Plain"], "~"],
        FontWeight->"Bold",
        FontSlant->"Italic"], "r"]}], "=", 
     RowBox[{"R", " ", 
      SubscriptBox[
       StyleBox[
        UnderscriptBox[
         StyleBox["e",
          FontSlant->"Plain"], "~"],
        FontWeight->"Bold",
        FontSlant->"Italic"], "r"]}]}]}], TraditionalForm]],ExpressionUUID->
  "7cd93127-ead7-4b0c-b04c-1475ab9774ac"],
 ", we get familiar equations for circular motion:\n\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderscriptBox["v", "~"], "=", 
    RowBox[{"R", " ", "\[Omega]", " ", 
     SubscriptBox[
      StyleBox[
       UnderscriptBox[
        StyleBox["e",
         FontSlant->"Plain"], "~"],
       FontWeight->"Bold",
       FontSlant->"Italic"], "\[CurlyTheta]"]}]}], TraditionalForm]],
  ExpressionUUID->"5f687913-4090-4a34-968c-9e14d98f6cbb"],
 ",  \n\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderscriptBox["a", "~"], "=", 
    RowBox[{
     RowBox[{"R", " ", 
      OverscriptBox["\[Omega]", "."], " ", 
      SubscriptBox[
       StyleBox[
        UnderscriptBox[
         StyleBox["e",
          FontSlant->"Plain"], "~"],
        FontWeight->"Bold",
        FontSlant->"Italic"], "\[CurlyTheta]"]}], "-", 
     RowBox[{"R", " ", 
      SuperscriptBox["\[Omega]", "2"], " ", 
      SubscriptBox[
       StyleBox[
        UnderscriptBox[
         StyleBox["e",
          FontSlant->"Plain"], "~"],
        FontWeight->"Bold",
        FontSlant->"Italic"], "r"]}]}]}], TraditionalForm]],ExpressionUUID->
  "21c05d6e-228d-42ea-a6e6-763a90deb383"],
 "\nwhere\n\t\[Omega]=g'[t] h[R]\nand\n\t",
 Cell[BoxData[
  FormBox[
   OverscriptBox["\[Omega]", "."], TraditionalForm]],ExpressionUUID->
  "ef73fe7d-5c15-4936-846a-764b80f7fed3"],
 "=g''[t]  h[R]"
}], "Text",
 CellChangeTimes->{{3.4852278471660147`*^9, 3.485227852391014*^9}, {
  3.485228104318014*^9, 3.4852281446360145`*^9}, {3.485228221983014*^9, 
  3.4852285746180143`*^9}, {3.4852286800640144`*^9, 3.4852290806440144`*^9}, {
  3.7507793898209896`*^9, 3.7507794707321463`*^9}, {3.750779624402076*^9, 
  3.7507796420984263`*^9}, {3.750780073937793*^9, 
  3.750780108241336*^9}},ExpressionUUID->"4ce621cb-a85a-4600-b721-\
7d943fcc4255"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Deformation gradient", "Section",
 CellChangeTimes->{{3.485230272047014*^9, 3.4852302725900145`*^9}, {
  3.485230364542014*^9, 
  3.485230381839014*^9}},ExpressionUUID->"126a11ac-a8d9-4b04-a844-\
8fc3b369355b"],

Cell[TextData[{
 "Let ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox[
     UnderscriptBox["E", "~"],
     FontWeight->"Bold",
     FontSlant->"Italic"], "R"], TraditionalForm]],ExpressionUUID->
  "221920e2-e754-4a3f-ba08-0ab3f7e345c1"],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     StyleBox[
      UnderscriptBox["E", "~"],
      FontWeight->"Bold",
      FontSlant->"Italic"], "\[CapitalTheta]"], ",", " ", 
    RowBox[{"and", "  ", 
     SubscriptBox[
      StyleBox[
       UnderscriptBox["E", "~"],
       FontWeight->"Bold",
       FontSlant->"Italic"], "z"]}]}], TraditionalForm]],ExpressionUUID->
  "20bcda42-99a9-4ad9-b1cd-a2c60fdcb75f"],
 " denote the reference cylindrical basis vectors (i.e., those corresponding \
to a particle\[CloseCurlyQuote]s initial position ",
 Cell[BoxData[
  FormBox[
   UnderscriptBox["X", "~"], TraditionalForm]],ExpressionUUID->
  "b82e44c0-c30f-46c2-9d80-20e8e6504442"],
 " on the path instead of its current position ",
 Cell[BoxData[
  FormBox[
   UnderscriptBox["x", "~"], TraditionalForm]],ExpressionUUID->
  "6e5ec80f-89f4-4b4c-8048-164efb0d40bd"],
 ").\n\nThe reference gradient of the rotation angle is given by\n\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox[
     RowBox[{"d", " ", "\[Alpha]"}], 
     RowBox[{"d", 
      UnderscriptBox["X", "~"]}]], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"g", "[", "t", "]"}], " ", 
      FractionBox[
       RowBox[{"d", " ", "h"}], 
       RowBox[{"d", " ", "R"}]], 
      FractionBox[
       RowBox[{"d", " ", "R"}], 
       RowBox[{"d", " ", 
        UnderscriptBox["X", "~"]}]]}], " ", "=", 
     RowBox[{
      RowBox[{"g", "[", "t", "]"}], " ", 
      RowBox[{
       RowBox[{"h", "'"}], "[", "R", "]"}], " ", 
      SubscriptBox[
       StyleBox[
        UnderscriptBox[
         StyleBox[
          RowBox[{"  ", "E"}],
          FontWeight->"Bold",
          FontSlant->"Plain"], "~"],
        FontWeight->"Bold",
        FontSlant->"Plain"], "R"], " "}]}]}], TraditionalForm]],
  ExpressionUUID->"cfc0ec7f-6ba1-4e80-b380-72b8c1b8cbbd"]
}], "Text",
 CellChangeTimes->{{3.4852199401820145`*^9, 3.485220079023014*^9}, 
   3.4852647832850704`*^9, {3.750780129208644*^9, 3.750780235738713*^9}, {
   3.750780377193549*^9, 
   3.750780385370966*^9}},ExpressionUUID->"be24ca1a-e41d-4249-862f-\
cd3939858b07"],

Cell[TextData[{
 "Recall that \n\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox[
     RowBox[{"d", 
      UnderscriptBox[
       UnderscriptBox["Q", "~"], "~"]}], "d\[Alpha]"], "=", 
    RowBox[{
     UnderscriptBox[
      UnderscriptBox["A", "~"], "~"], ".", " ", 
     UnderscriptBox[
      UnderscriptBox["Q", "~"], "~"]}]}], TraditionalForm]],ExpressionUUID->
  "a7021aa1-3633-4b70-ae3e-754d42373f8c"],
 "\nThe deformation gradient is\n\t",
 Cell[BoxData[{
  FormBox[
   RowBox[{
    UnderscriptBox[
     UnderscriptBox["F", "~"], "~"], "=", 
    RowBox[{
     FractionBox[
      RowBox[{"d", " ", 
       UnderscriptBox["x", "~"]}], 
      RowBox[{"d", " ", 
       UnderscriptBox["X", "~"]}]], "=", 
     FractionBox[
      RowBox[{"d", "(", 
       RowBox[{
        UnderscriptBox[
         UnderscriptBox["Q", "~"], "~"], ".", " ", 
        UnderscriptBox["X", "~"]}], ")"}], 
      RowBox[{"d", " ", 
       UnderscriptBox["X", "~"]}]]}]}], 
   TraditionalForm], "\[IndentingNewLine]", 
  FormBox[
   RowBox[{"=", 
    RowBox[{
     UnderscriptBox[
      UnderscriptBox["Q", "~"], "~"], "+", 
     RowBox[{
      UnderscriptBox["X", "~"], ".", 
      FractionBox[
       RowBox[{"d", 
        SuperscriptBox[
         UnderscriptBox[
          UnderscriptBox["Q", "~"], "~"], "T"]}], 
       RowBox[{"d", 
        UnderscriptBox["X", "~"]}]]}]}]}], 
   TraditionalForm], "\[IndentingNewLine]", 
  FormBox[
   RowBox[{"=", 
    RowBox[{
     UnderscriptBox[
      UnderscriptBox["Q", "~"], "~"], "+", 
     RowBox[{
      RowBox[{
       UnderscriptBox["X", "~"], ".", 
       FractionBox[
        RowBox[{"d", 
         SuperscriptBox[
          UnderscriptBox[
           UnderscriptBox["Q", "~"], "~"], "T"]}], "d\[Alpha]"]}], 
      FractionBox[
       RowBox[{"d", " ", "\[Alpha]"}], 
       RowBox[{"d", 
        UnderscriptBox["X", "~"]}]]}]}]}], 
   TraditionalForm], "\[IndentingNewLine]", 
  FormBox[
   RowBox[{
    RowBox[{"=", " ", 
     RowBox[{
      UnderscriptBox[
       UnderscriptBox["Q", "~"], "~"], "+", 
      RowBox[{
       RowBox[{
        UnderscriptBox["X", "~"], ".", 
        FractionBox[
         RowBox[{"d", 
          SuperscriptBox[
           UnderscriptBox[
            UnderscriptBox["Q", "~"], "~"], "T"]}], "d\[Alpha]"]}], 
       RowBox[{"g", "[", "t", "]"}], " ", 
       RowBox[{
        RowBox[{"h", "'"}], "[", "R", "]"}], " ", 
       SubscriptBox[
        StyleBox[
         UnderscriptBox[
          StyleBox[
           RowBox[{"  ", "E"}],
           FontWeight->"Bold",
           FontSlant->"Plain"], "~"],
         FontWeight->"Bold",
         FontSlant->"Plain"], "R"]}]}]}], " "}], 
   TraditionalForm], "\[IndentingNewLine]", 
  FormBox[
   RowBox[{"=", " ", 
    RowBox[{
     UnderscriptBox[
      UnderscriptBox["Q", "~"], "~"], "+", 
     RowBox[{
      RowBox[{"g", "[", "t", "]"}], " ", 
      RowBox[{
       RowBox[{"h", "'"}], "[", "R", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"d", 
          UnderscriptBox[
           UnderscriptBox["Q", "~"], "~"]}], "d\[Alpha]"], ".", 
        UnderscriptBox["X", "~"]}], ")"}], 
      SubscriptBox[
       StyleBox[
        UnderscriptBox[
         StyleBox[
          RowBox[{"  ", "E"}],
          FontWeight->"Bold",
          FontSlant->"Plain"], "~"],
        FontWeight->"Bold",
        FontSlant->"Plain"], "R"]}]}]}], 
   TraditionalForm], "\[IndentingNewLine]", 
  FormBox[
   RowBox[{"=", " ", 
    RowBox[{
     UnderscriptBox[
      UnderscriptBox["Q", "~"], "~"], "+", 
     RowBox[{
      RowBox[{"g", "[", "t", "]"}], " ", 
      RowBox[{
       RowBox[{"h", "'"}], "[", "R", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        UnderscriptBox[
         UnderscriptBox["A", "~"], "~"], ".", " ", 
        UnderscriptBox[
         UnderscriptBox["Q", "~"], "~"], ".", 
        UnderscriptBox["X", "~"]}], ")"}], 
      SubscriptBox[
       StyleBox[
        UnderscriptBox[
         StyleBox[
          RowBox[{"  ", "E"}],
          FontWeight->"Bold",
          FontSlant->"Plain"], "~"],
        FontWeight->"Bold",
        FontSlant->"Plain"], "R"]}]}]}], 
   TraditionalForm], "\[IndentingNewLine]", 
  FormBox[
   RowBox[{"=", 
    RowBox[{
     UnderscriptBox[
      UnderscriptBox["Q", "~"], "~"], ".", 
     RowBox[{"(", 
      RowBox[{
       UnderscriptBox[
        UnderscriptBox["I", "~"], "~"], "+", 
       RowBox[{
        RowBox[{"g", "[", "t", "]"}], " ", 
        RowBox[{
         RowBox[{"h", "'"}], "[", "R", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          UnderscriptBox[
           UnderscriptBox["A", "~"], "~"], ".", 
          UnderscriptBox["X", "~"]}], ")"}], 
        SubscriptBox[
         StyleBox[
          UnderscriptBox[
           StyleBox[
            RowBox[{"  ", "E"}],
            FontWeight->"Bold",
            FontSlant->"Plain"], "~"],
          FontWeight->"Bold",
          FontSlant->"Plain"], "R"]}]}], ")"}]}]}], 
   TraditionalForm], "\[IndentingNewLine]", 
  FormBox[
   RowBox[{"=", 
    RowBox[{
     UnderscriptBox[
      UnderscriptBox["Q", "~"], "~"], ".", 
     RowBox[{"(", 
      RowBox[{
       UnderscriptBox[
        UnderscriptBox["I", "~"], "~"], "+", 
       RowBox[{
        RowBox[{"g", "[", "t", "]"}], " ", "R", " ", 
        RowBox[{
         RowBox[{"h", "'"}], "[", "R", "]"}], " ", 
        SubscriptBox[
         StyleBox[
          UnderscriptBox[
           StyleBox[
            RowBox[{"  ", "E"}],
            FontWeight->"Bold",
            FontSlant->"Plain"], "~"],
          FontWeight->"Bold",
          FontSlant->"Plain"], "\[CapitalTheta]"], 
        SubscriptBox[
         StyleBox[
          UnderscriptBox[
           StyleBox[
            RowBox[{"  ", "E"}],
            FontWeight->"Bold",
            FontSlant->"Plain"], "~"],
          FontWeight->"Bold",
          FontSlant->"Plain"], "R"]}]}], ")"}]}]}], TraditionalForm]}],
  ExpressionUUID->"98b4b955-03cc-425c-a898-8471c38324f7"],
 "\nIn the penultimate step, we used the easily confirmed fact that  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox[
    UnderscriptBox[
     UnderscriptBox["Q", "~"], "~"], "T"], ".", 
   UnderscriptBox[
    UnderscriptBox["A", "~"], "~"], ".", " ", 
   UnderscriptBox[
    UnderscriptBox["Q", "~"], "~"]}]],ExpressionUUID->
  "1c972cc0-a8ec-4b69-9dea-1a913e6d8b2e"],
 " = ",
 Cell[BoxData[
  UnderscriptBox[
   UnderscriptBox["A", "~"], "~"]],ExpressionUUID->
  "f8b60733-15ab-48dc-874c-4cd6ce1faf76"],
 ".\nIn the ultimate step, it was observed that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     UnderscriptBox[
      UnderscriptBox["A", "~"], "~"], ".", 
     UnderscriptBox["X", "~"]}], "=", 
    RowBox[{
     UnderscriptBox[
      UnderscriptBox["A", "~"], "~"], ".", 
     RowBox[{"(", 
      RowBox[{"R", 
       SubscriptBox[
        StyleBox[
         UnderscriptBox[
          StyleBox[
           RowBox[{"  ", "E"}],
           FontWeight->"Bold",
           FontSlant->"Plain"], "~"],
         FontWeight->"Bold",
         FontSlant->"Plain"], "R"]}], ")"}]}]}], TraditionalForm]],
  ExpressionUUID->"224aecff-66cf-46ab-a0e2-70b465092b31"],
 " = ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"R", 
     RowBox[{
      UnderscriptBox[
       UnderscriptBox["A", "~"], "~"], ".", 
      SubscriptBox[
       StyleBox[
        UnderscriptBox[
         StyleBox[
          RowBox[{" ", "E"}],
          FontWeight->"Bold",
          FontSlant->"Plain"], "~"],
        FontWeight->"Bold",
        FontSlant->"Plain"], "R"]}]}], "=", " ", 
    RowBox[{"R", 
     SubscriptBox[
      StyleBox[
       UnderscriptBox[
        StyleBox[
         RowBox[{" ", "E"}],
         FontWeight->"Bold",
         FontSlant->"Plain"], "~"],
       FontWeight->"Bold",
       FontSlant->"Plain"], "\[CapitalTheta]"]}]}], TraditionalForm]],
  ExpressionUUID->"57be3e81-01ad-4a51-ac0f-c2afc28326a3"],
 "\n\nThe result\n\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderscriptBox[
     UnderscriptBox["F", "~"], "~"], "="}], TraditionalForm]],ExpressionUUID->
  "51758a1c-c837-40f4-a938-a4d1be174839"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderscriptBox[
     UnderscriptBox["Q", "~"], "~"], ".", 
    RowBox[{"(", 
     RowBox[{
      UnderscriptBox[
       UnderscriptBox["I", "~"], "~"], "+", 
      RowBox[{
       RowBox[{"g", "[", "t", "]"}], " ", "R", " ", 
       RowBox[{
        RowBox[{"h", "'"}], "[", "R", "]"}], " ", 
       SubscriptBox[
        StyleBox[
         UnderscriptBox[
          StyleBox[
           RowBox[{"  ", "E"}],
           FontWeight->"Bold",
           FontSlant->"Plain"], "~"],
         FontWeight->"Bold",
         FontSlant->"Plain"], "\[CapitalTheta]"], 
       SubscriptBox[
        StyleBox[
         UnderscriptBox[
          StyleBox[
           RowBox[{"  ", "E"}],
           FontWeight->"Bold",
           FontSlant->"Plain"], "~"],
         FontWeight->"Bold",
         FontSlant->"Plain"], "R"]}]}], ")"}]}], TraditionalForm]],
  ExpressionUUID->"9594cea7-b596-4fd9-8694-47eebb502171"],
 "\nis  a state of simple shear in the \[CapitalTheta] direction with shear \
plane tangent to the circumference, and with superimposed rotation.  \n\n\n\
Define\n\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Xi]", "[", "R", "]"}], "=", 
    FractionBox["1", "2"]}], TraditionalForm]],ExpressionUUID->
  "fb5fd394-622b-4ea3-9d59-6f42974d837a"],
 "R h'[R]\nThen the large-deformation shear strain is\n\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Epsilon]", "[", 
     RowBox[{"t", ",", "R"}], "]"}], "=", 
    RowBox[{
     RowBox[{"g", "[", "t", "]"}], 
     RowBox[{"\[Xi]", "[", "R", "]"}], " "}]}], TraditionalForm]],
  ExpressionUUID->"bf01dff7-4ecd-44d1-a497-9daa59d1e9b1"],
 "\n\t\nThe deformation gradient may be written as\n\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderscriptBox[
     UnderscriptBox["F", "~"], "~"], "=", 
    RowBox[{
     UnderscriptBox[
      UnderscriptBox["Q", "~"], "~"], ".", 
     UnderscriptBox[
      UnderscriptBox["q", "~"], "~"], ".", 
     UnderscriptBox[
      UnderscriptBox["\[ScriptCapitalF]", "~"], "~"], ".", 
     SuperscriptBox[
      UnderscriptBox[
       UnderscriptBox["q", "~"], "~"], "T"]}]}], TraditionalForm]],
  ExpressionUUID->"4584afcf-a26b-48b6-a734-10356c0964e6"],
 "\nwhere\n\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderscriptBox[
     UnderscriptBox["\[ScriptCapitalF]", "~"], "~"], "=", 
    RowBox[{
     UnderscriptBox[
      UnderscriptBox["I", "~"], "~"], "+", 
     RowBox[{"2", 
      RowBox[{"g", "[", "t", "]"}], 
      RowBox[{"\[Xi]", "[", "R", "]"}], 
      SubscriptBox[
       StyleBox[
        UnderscriptBox[
         StyleBox[
          RowBox[{"  ", "E"}],
          FontWeight->"Bold",
          FontSlant->"Plain"], "~"],
        FontWeight->"Bold",
        FontSlant->"Plain"], "2"], 
      SubscriptBox[
       StyleBox[
        UnderscriptBox[
         StyleBox[
          RowBox[{"  ", "E"}],
          FontWeight->"Bold",
          FontSlant->"Plain"], "~"],
        FontWeight->"Bold",
        FontSlant->"Plain"], "1"]}]}]}], TraditionalForm]],ExpressionUUID->
  "25a7fc5a-6344-4f58-94a7-838d312506aa"],
 "\n\t\n\t",
 Cell[BoxData[
  FormBox[
   UnderscriptBox[
    UnderscriptBox["q", "~"], "~"], TraditionalForm]],ExpressionUUID->
  "77baa078-50a4-4156-8b37-ce4b95347ead"],
 "=",
 Cell[BoxData[
  RowBox[{"(", GridBox[{
     {
      RowBox[{"Cos", "[", "\[CapitalTheta]", "]"}], 
      RowBox[{"-", 
       RowBox[{"Sin", "[", "\[CapitalTheta]", "]"}]}], "0"},
     {
      RowBox[{"Sin", "[", "\[CapitalTheta]", "]"}], 
      RowBox[{"Cos", "[", "\[CapitalTheta]", "]"}], "0"},
     {"0", "0", "1"}
    }], ")"}]],
  CellChangeTimes->{{3.4852186467960143`*^9, 3.4852186848810143`*^9}, {
   3.485218872365014*^9, 3.4852190028990145`*^9}},ExpressionUUID->
  "7892d56e-1c8f-475b-aad0-88c32cf1cc1a"],
 "\nNote that \n\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderscriptBox[
     UnderscriptBox["F", "~"], "~"], "="}], TraditionalForm]],ExpressionUUID->
  "616302ee-b990-4c6e-9e4d-6f1d58b738f4"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderscriptBox[
     UnderscriptBox["r", "~"], "~"], ".", 
    UnderscriptBox[
     UnderscriptBox["\[ScriptCapitalF]", "~"], "~"], ".", 
    SuperscriptBox[
     UnderscriptBox[
      UnderscriptBox["q", "~"], "~"], "T"]}], TraditionalForm]],
  ExpressionUUID->"36fd8215-6da8-4d23-8cad-20750a5d3cc2"],
 "\nwhere\n\t",
 Cell[BoxData[
  FormBox[
   UnderscriptBox[
    UnderscriptBox["r", "~"], "~"], TraditionalForm]],ExpressionUUID->
  "a01ce1a0-e65b-4505-803e-b795812a7dcc"],
 "=",
 Cell[BoxData[
  RowBox[{"(", GridBox[{
     {
      RowBox[{"Cos", "[", "\[CurlyTheta]", "]"}], 
      RowBox[{"-", 
       RowBox[{"Sin", "[", "\[CurlyTheta]", "]"}]}], "0"},
     {
      RowBox[{"Sin", "[", "\[CurlyTheta]", "]"}], 
      RowBox[{"Cos", "[", "\[CurlyTheta]", "]"}], "0"},
     {"0", "0", "1"}
    }], ")"}]],
  CellChangeTimes->{{3.4852186467960143`*^9, 3.4852186848810143`*^9}, {
   3.485218872365014*^9, 3.4852190028990145`*^9}},ExpressionUUID->
  "fb4d4ec1-2aa2-47e4-bfcc-2e4f82fcdd9b"]
}], "Text",
 CellChangeTimes->{{3.485219513056014*^9, 3.4852198305270147`*^9}, {
   3.485219896726014*^9, 3.4852199238120146`*^9}, 3.4852200966690145`*^9, {
   3.4852201412080145`*^9, 3.4852204012500143`*^9}, {3.4852204930960145`*^9, 
   3.4852205560620146`*^9}, {3.4852206143860145`*^9, 
   3.4852206583220143`*^9}, {3.4852207058090143`*^9, 3.485220767167014*^9}, {
   3.485220801726014*^9, 3.4852209661750145`*^9}, {3.4852209995500145`*^9, 
   3.4852211835950146`*^9}, {3.4852212224670143`*^9, 3.485221589207014*^9}, {
   3.4852216417800145`*^9, 3.4852217135330143`*^9}, {3.4852220139750147`*^9, 
   3.4852220222390146`*^9}, {3.4852224804380145`*^9, 3.4852225663200145`*^9}, 
   3.4852226095630145`*^9, {3.4852239510200143`*^9, 3.4852240065630145`*^9}, {
   3.4852244139330144`*^9, 3.4852244174490147`*^9}, {3.485264936149739*^9, 
   3.4852649991582494`*^9}, {3.7507802762987595`*^9, 
   3.7507803712844343`*^9}, {3.7507804110747805`*^9, 
   3.750780441412113*^9}},ExpressionUUID->"1cb431de-dbef-4728-ad45-\
4379d4be47ae"],

Cell[TextData[{
 "Note that ",
 Cell[BoxData[
  FormBox[
   UnderscriptBox[
    UnderscriptBox["\[ScriptCapitalF]", "~"], "~"], TraditionalForm]],
  ExpressionUUID->"011f9579-ce33-4eb7-9036-57651272b372"],
 " is independent of the angular coordinate, and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox[
     RowBox[{"d", " ", 
      UnderscriptBox[
       UnderscriptBox["\[ScriptCapitalF]", "~"], "~"]}], 
     RowBox[{"d", " ", "R"}]], "=", 
    RowBox[{"2", 
     RowBox[{"g", "[", "t", "]"}], 
     RowBox[{
      RowBox[{"\[Xi]", "'"}], "[", "R", "]"}], 
     SubscriptBox[
      StyleBox[
       UnderscriptBox[
        StyleBox[
         RowBox[{"  ", "E"}],
         FontWeight->"Bold",
         FontSlant->"Plain"], "~"],
       FontWeight->"Bold",
       FontSlant->"Plain"], "2"], 
     SubscriptBox[
      StyleBox[
       UnderscriptBox[
        StyleBox[
         RowBox[{"  ", "E"}],
         FontWeight->"Bold",
         FontSlant->"Plain"], "~"],
       FontWeight->"Bold",
       FontSlant->"Plain"], "1"]}]}], TraditionalForm]],ExpressionUUID->
  "2ab8f146-edba-4ec8-951b-0ce961ed6905"],
 "\nNote that ",
 Cell[BoxData[
  FormBox[
   UnderscriptBox[
    UnderscriptBox["q", "~"], "~"], TraditionalForm]],ExpressionUUID->
  "9718feb3-6bca-46e5-9de9-483aff9c58a4"],
 " is independent of the radial coordinate, and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox[
     RowBox[{"d", " ", 
      UnderscriptBox[
       UnderscriptBox["q", "~"], "~"]}], 
     RowBox[{"d", " ", "\[CapitalTheta]"}]], "=", 
    RowBox[{
     UnderscriptBox[
      UnderscriptBox["A", "~"], "~"], ".", 
     UnderscriptBox[
      UnderscriptBox["q", "~"], "~"]}]}], TraditionalForm]],ExpressionUUID->
  "b8d02b03-4ead-4eba-912d-23825ba91457"],
 "\nNote that ",
 Cell[BoxData[
  FormBox[
   UnderscriptBox[
    UnderscriptBox["r", "~"], "~"], TraditionalForm]],ExpressionUUID->
  "d1c5e3a6-8bd7-4869-bec2-d922c04ac5c5"],
 " depends on both angular and radial coordinates.  Noting that \[CurlyTheta] \
= \[CapitalTheta]+\[Alpha] = \[CapitalTheta]+g[t]h[R], we have\n\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox[
     RowBox[{"d", " ", 
      UnderscriptBox[
       UnderscriptBox["r", "~"], "~"]}], 
     RowBox[{"d", " ", "\[CurlyTheta]"}]], "=", 
    RowBox[{
     UnderscriptBox[
      UnderscriptBox["A", "~"], "~"], ".", 
     UnderscriptBox[
      UnderscriptBox["r", "~"], "~"]}]}], TraditionalForm]],ExpressionUUID->
  "e64513d3-e0a6-4009-9c09-4ee968939f98"],
 "\n\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     RowBox[{"(", 
      FractionBox[
       RowBox[{"\[PartialD]", " ", 
        UnderscriptBox[
         UnderscriptBox["r", "~"], "~"]}], 
       RowBox[{"\[PartialD]", " ", "\[CapitalTheta]"}]], ")"}], "R"], "=", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"d", " ", 
        UnderscriptBox[
         UnderscriptBox["r", "~"], "~"]}], 
       RowBox[{"d", " ", "\[CurlyTheta]"}]], 
      FractionBox[
       RowBox[{"\[PartialD]", "\[CurlyTheta]"}], 
       RowBox[{"\[PartialD]", "\[CapitalTheta]"}]]}], "=", 
     RowBox[{
      UnderscriptBox[
       UnderscriptBox["A", "~"], "~"], ".", 
      UnderscriptBox[
       UnderscriptBox["r", "~"], "~"]}]}]}], TraditionalForm]],
  ExpressionUUID->"84b065ab-486e-406e-b7eb-88028c1166af"],
 "\n\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     RowBox[{"(", 
      FractionBox[
       RowBox[{"\[PartialD]", " ", 
        UnderscriptBox[
         UnderscriptBox["r", "~"], "~"]}], 
       RowBox[{"\[PartialD]", " ", "R"}]], ")"}], "\[CapitalTheta]"], "=", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"d", " ", 
        UnderscriptBox[
         UnderscriptBox["r", "~"], "~"]}], 
       RowBox[{"d", " ", "\[CurlyTheta]"}]], 
      FractionBox[
       RowBox[{"\[PartialD]", "\[CurlyTheta]"}], 
       RowBox[{"\[PartialD]", "R"}]]}], "=", 
     RowBox[{
      RowBox[{"g", "[", "t", "]"}], 
      RowBox[{
       RowBox[{"h", "'"}], "[", "R", "]"}], 
      RowBox[{
       UnderscriptBox[
        UnderscriptBox["A", "~"], "~"], ".", 
       UnderscriptBox[
        UnderscriptBox["r", "~"], "~"]}]}]}]}], TraditionalForm]],
  ExpressionUUID->"2d07a173-e837-4c71-b27a-79e857fe5060"]
}], "Text",
 CellChangeTimes->{{3.485222030205014*^9, 3.4852220551640143`*^9}, {
  3.4852221121430144`*^9, 3.4852221428260145`*^9}, {3.4852221816990147`*^9, 
  3.4852222642810144`*^9}, {3.4852223080010147`*^9, 3.4852223779930143`*^9}, {
  3.4852226252420144`*^9, 3.485222685497014*^9}, {3.4852227233130145`*^9, 
  3.485223166613014*^9}, {3.4852651876533804`*^9, 
  3.485265192099388*^9}},ExpressionUUID->"a1ba11b3-5ff2-4b6c-b1f0-\
daa2e452e1ad"],

Cell[TextData[{
 "Using all of these things, the gradient of the deformation gradient (which \
is here for completeness to help any future efforts to include gradient \
plasticity, but isn't used again here in this notebook) is\n\n",
 Cell[BoxData[{
  FormBox[
   RowBox[{
    FractionBox[
     RowBox[{"d", 
      UnderscriptBox[
       UnderscriptBox["F", "~"], "~"]}], 
     RowBox[{"d", " ", 
      UnderscriptBox["X", "~"]}]], "=", 
    RowBox[{
     RowBox[{
      SubscriptBox[
       RowBox[{"(", 
        FractionBox[
         RowBox[{"\[PartialD]", " ", 
          UnderscriptBox[
           UnderscriptBox["F", "~"], "~"]}], 
         RowBox[{"\[PartialD]", " ", "R"}]], ")"}], "\[CapitalTheta]"], 
      SubscriptBox[
       StyleBox[
        UnderscriptBox[
         StyleBox["E",
          FontWeight->"Bold",
          FontSlant->"Plain"], "~"],
        FontWeight->"Bold",
        FontSlant->"Plain"], "R"]}], "+", 
     RowBox[{
      FractionBox["1", "R"], 
      SubscriptBox[
       RowBox[{"(", 
        FractionBox[
         RowBox[{"\[PartialD]", " ", 
          UnderscriptBox[
           UnderscriptBox["F", "~"], "~"]}], 
         RowBox[{"\[PartialD]", " ", "\[CapitalTheta]"}]], ")"}], "R"], 
      SubscriptBox[
       StyleBox[
        UnderscriptBox[
         StyleBox["E",
          FontWeight->"Bold",
          FontSlant->"Plain"], "~"],
        FontWeight->"Bold",
        FontSlant->"Plain"], "\[CapitalTheta]"]}]}]}], 
   TraditionalForm], "\[IndentingNewLine]", 
  FormBox[
   RowBox[{"=", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"g", "[", "t", "]"}], 
         RowBox[{
          RowBox[{"h", "'"}], "[", "R", "]"}], 
         RowBox[{
          UnderscriptBox[
           UnderscriptBox["A", "~"], "~"], ".", 
          UnderscriptBox[
           UnderscriptBox["F", "~"], "~"]}]}], "+", 
        RowBox[{
         UnderscriptBox[
          UnderscriptBox["r", "~"], "~"], ".2", 
         RowBox[{"g", "[", "t", "]"}], 
         RowBox[{
          RowBox[{"\[Xi]", "'"}], "[", "R", "]"}], 
         SubscriptBox[
          StyleBox[
           UnderscriptBox[
            StyleBox[
             RowBox[{"  ", "E"}],
             FontWeight->"Bold",
             FontSlant->"Plain"], "~"],
           FontWeight->"Bold",
           FontSlant->"Plain"], "2"], 
         RowBox[{
          SubscriptBox[
           StyleBox[
            UnderscriptBox[
             StyleBox[
              RowBox[{"  ", "E"}],
              FontWeight->"Bold",
              FontSlant->"Plain"], "~"],
            FontWeight->"Bold",
            FontSlant->"Plain"], "1"], ".", 
          SuperscriptBox[
           UnderscriptBox[
            UnderscriptBox["q", "~"], "~"], "T"]}]}]}], ")"}], 
      SubscriptBox[
       StyleBox[
        UnderscriptBox[
         StyleBox["E",
          FontWeight->"Bold",
          FontSlant->"Plain"], "~"],
        FontWeight->"Bold",
        FontSlant->"Plain"], "R"]}], "+", 
     RowBox[{
      FractionBox["1", "R"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         UnderscriptBox[
          UnderscriptBox["A", "~"], "~"], ".", 
         UnderscriptBox[
          UnderscriptBox["F", "~"], "~"]}], "+", 
        RowBox[{
         UnderscriptBox[
          UnderscriptBox["F", "~"], "~"], ".", 
         SuperscriptBox[
          UnderscriptBox[
           UnderscriptBox["A", "~"], "~"], "T"]}]}], ")"}], 
      SubscriptBox[
       StyleBox[
        UnderscriptBox[
         StyleBox["E",
          FontWeight->"Bold",
          FontSlant->"Plain"], "~"],
        FontWeight->"Bold",
        FontSlant->"Plain"], "\[CapitalTheta]"]}]}]}], 
   TraditionalForm], "\[IndentingNewLine]", 
  FormBox[
   RowBox[{"=", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"g", "[", "t", "]"}], 
         RowBox[{
          RowBox[{"h", "'"}], "[", "R", "]"}], 
         RowBox[{
          UnderscriptBox[
           UnderscriptBox["A", "~"], "~"], ".", 
          UnderscriptBox[
           UnderscriptBox["F", "~"], "~"]}]}], "+", 
        RowBox[{"2", 
         RowBox[{"g", "[", "t", "]"}], 
         RowBox[{
          RowBox[{"\[Xi]", "'"}], "[", "R", "]"}], 
         SubscriptBox[
          StyleBox[
           UnderscriptBox[
            RowBox[{
             StyleBox["  ",
              FontWeight->"Plain",
              FontSlant->"Italic"], 
             StyleBox["e",
              FontSlant->"Plain"]}], "~"],
           FontWeight->"Bold",
           FontSlant->"Plain"], "\[CurlyTheta]"], 
         SubscriptBox[
          StyleBox[
           UnderscriptBox[
            StyleBox["E",
             FontWeight->"Bold",
             FontSlant->"Plain"], "~"],
           FontWeight->"Bold",
           FontSlant->"Plain"], "R"]}]}], ")"}], 
      SubscriptBox[
       StyleBox[
        UnderscriptBox[
         StyleBox["E",
          FontWeight->"Bold",
          FontSlant->"Plain"], "~"],
        FontWeight->"Bold",
        FontSlant->"Plain"], "R"]}], "+", 
     RowBox[{
      FractionBox["1", "R"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         UnderscriptBox[
          UnderscriptBox["A", "~"], "~"], ".", 
         UnderscriptBox[
          UnderscriptBox["F", "~"], "~"]}], "+", 
        RowBox[{
         UnderscriptBox[
          UnderscriptBox["F", "~"], "~"], ".", 
         SuperscriptBox[
          UnderscriptBox[
           UnderscriptBox["A", "~"], "~"], "T"]}]}], ")"}], 
      SubscriptBox[
       StyleBox[
        UnderscriptBox[
         StyleBox["E",
          FontWeight->"Bold",
          FontSlant->"Plain"], "~"],
        FontWeight->"Bold",
        FontSlant->"Plain"], "\[CapitalTheta]"]}]}]}], TraditionalForm]}],
  ExpressionUUID->"7ab0bf98-a235-4cef-b891-25c7b32d480a"]
}], "Text",
 CellChangeTimes->{{3.4852231714750147`*^9, 3.4852236674510145`*^9}, 
   3.4852236975270147`*^9, {3.4852237592800145`*^9, 3.4852238697870145`*^9}, 
   3.4852257168190145`*^9, {3.4852653022511816`*^9, 3.4852653146844034`*^9}, {
   3.75078051620122*^9, 
   3.750780534569457*^9}},ExpressionUUID->"322ef6eb-7754-4ce1-8da6-\
35431712f05c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"R", " ", 
     RowBox[{"Cos", "[", "\[Alpha]", "]"}], " ", 
     RowBox[{"Cos", "[", "\[CapitalTheta]", "]"}]}], "-", 
    RowBox[{"R", " ", 
     RowBox[{"Sin", "[", "\[Alpha]", "]"}], " ", 
     RowBox[{"Sin", "[", "\[CapitalTheta]", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"R", " ", 
     RowBox[{"Cos", "[", "\[CapitalTheta]", "]"}], " ", 
     RowBox[{"Sin", "[", "\[Alpha]", "]"}]}], "+", 
    RowBox[{"R", " ", 
     RowBox[{"Cos", "[", "\[Alpha]", "]"}], " ", 
     RowBox[{"Sin", "[", "\[CapitalTheta]", "]"}]}]}], ",", "0"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.4852194858520145`*^9},ExpressionUUID->"93cc5100-c29c-479a-8de6-\
3120a586da1b"],

Cell[TextData[{
 "Recall that\n\t ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderscriptBox[
     UnderscriptBox["\[ScriptCapitalF]", "~"], "~"], "=", 
    RowBox[{
     UnderscriptBox[
      UnderscriptBox["I", "~"], "~"], "+", 
     RowBox[{"2", 
      RowBox[{"\[Epsilon]", "[", 
       RowBox[{"t", ",", "R"}], "]"}], 
      SubscriptBox[
       StyleBox[
        UnderscriptBox[
         StyleBox[
          RowBox[{"  ", "E"}],
          FontWeight->"Bold",
          FontSlant->"Plain"], "~"],
        FontWeight->"Bold",
        FontSlant->"Plain"], "2"], 
      SubscriptBox[
       StyleBox[
        UnderscriptBox[
         StyleBox[
          RowBox[{"  ", "E"}],
          FontWeight->"Bold",
          FontSlant->"Plain"], "~"],
        FontWeight->"Bold",
        FontSlant->"Plain"], "1"]}]}]}], TraditionalForm]],ExpressionUUID->
  "c5113a57-3826-4560-bc51-60bfa6f18cd5"],
 "\nThis is a pure shear.  Suppose that the material is homogeneous and \
isotropic.  Let ",
 Cell[BoxData[
  FormBox[
   UnderscriptBox[
    UnderscriptBox["\[ScriptCapitalS]", "~"], "~"], TraditionalForm]],
  ExpressionUUID->"5336c1e4-ed25-40f6-86ac-43023fd906ff"],
 " denote the second-Piola Kirchhoff  (PK2) stress associated with the \
deformation ",
 Cell[BoxData[
  FormBox[
   UnderscriptBox[
    UnderscriptBox["\[ScriptCapitalF]", "~"], "~"], TraditionalForm]],
  ExpressionUUID->"526fb991-471a-4b99-a38e-a23705078c56"],
 ".  Then, for an isotropic material, it follows that the PK2 stress \
associated with ",
 Cell[BoxData[
  FormBox[
   UnderscriptBox[
    UnderscriptBox["F", "~"], "~"], TraditionalForm]],ExpressionUUID->
  "725fc53c-e48f-4802-be8f-928bc905d20c"],
 " must be\n\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderscriptBox[
     UnderscriptBox["S", "~"], "~"], "=", 
    RowBox[{
     UnderscriptBox[
      UnderscriptBox["q", "~"], "~"], ".", 
     UnderscriptBox[
      UnderscriptBox["\[ScriptCapitalS]", "~"], "~"], ".", 
     SuperscriptBox[
      UnderscriptBox[
       UnderscriptBox["q", "~"], "~"], "T"]}]}], TraditionalForm]],
  ExpressionUUID->"a055a184-787e-481f-a9bf-270cb2bb73a0"],
 "\nThe first Piola-Kirchhoff (PK1) stress is then\n\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderscriptBox[
     UnderscriptBox["T", "~"], "~"], "=", 
    RowBox[{
     RowBox[{
      UnderscriptBox[
       UnderscriptBox["F", "~"], "~"], ".", 
      UnderscriptBox[
       UnderscriptBox["S", "~"], "~"]}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         UnderscriptBox[
          UnderscriptBox["Q", "~"], "~"], ".", 
         UnderscriptBox[
          UnderscriptBox["q", "~"], "~"], ".", 
         UnderscriptBox[
          UnderscriptBox["\[ScriptCapitalF]", "~"], "~"], ".", 
         SuperscriptBox[
          UnderscriptBox[
           UnderscriptBox["q", "~"], "~"], "T"]}], ")"}], ".", 
       RowBox[{"(", 
        RowBox[{
         UnderscriptBox[
          UnderscriptBox["q", "~"], "~"], ".", 
         UnderscriptBox[
          UnderscriptBox["\[ScriptCapitalS]", "~"], "~"], ".", 
         SuperscriptBox[
          UnderscriptBox[
           UnderscriptBox["q", "~"], "~"], "T"]}], ")"}]}], "=", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         UnderscriptBox[
          UnderscriptBox["Q", "~"], "~"], ".", 
         UnderscriptBox[
          UnderscriptBox["q", "~"], "~"], ".", 
         UnderscriptBox[
          UnderscriptBox["\[ScriptCapitalF]", "~"], "~"], ".", 
         UnderscriptBox[
          UnderscriptBox["\[ScriptCapitalS]", "~"], "~"], ".", 
         SuperscriptBox[
          UnderscriptBox[
           UnderscriptBox["q", "~"], "~"], "T"]}], ")"}], "=", 
       RowBox[{
        UnderscriptBox[
         UnderscriptBox["Q", "~"], "~"], ".", 
        UnderscriptBox[
         UnderscriptBox["q", "~"], "~"], ".", 
        UnderscriptBox[
         UnderscriptBox["\[ScriptCapitalT]", "~"], "~"], ".", 
        SuperscriptBox[
         UnderscriptBox[
          UnderscriptBox["q", "~"], "~"], "T"]}]}]}]}]}], TraditionalForm]],
  ExpressionUUID->"2c407d06-949f-4db3-a3f7-732cb0f584a5"],
 "\nor\n\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderscriptBox[
     UnderscriptBox["T", "~"], "~"], "=", 
    RowBox[{
     UnderscriptBox[
      UnderscriptBox["r", "~"], "~"], ".", 
     UnderscriptBox[
      UnderscriptBox["\[ScriptCapitalT]", "~"], "~"], ".", 
     SuperscriptBox[
      UnderscriptBox[
       UnderscriptBox["q", "~"], "~"], "T"]}]}], TraditionalForm]],
  ExpressionUUID->"9670e6f6-85c5-415e-ad53-91682a769dd1"],
 "\n\twhere \n\t\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderscriptBox[
     UnderscriptBox["\[ScriptCapitalT]", "~"], "~"], "="}], TraditionalForm]],
  ExpressionUUID->"3a71e720-83e6-4f4c-b614-5040b0ba1483"],
 Cell[BoxData[
  RowBox[{
   UnderscriptBox[
    UnderscriptBox["\[ScriptCapitalF]", "~"], "~"], ".", 
   UnderscriptBox[
    UnderscriptBox["\[ScriptCapitalS]", "~"], "~"]}]],ExpressionUUID->
  "c51ea6a3-06d8-477d-9f0f-719a811ad171"],
 "\n\tis the PK1 stress associated with deformation ",
 Cell[BoxData[
  FormBox[
   UnderscriptBox[
    UnderscriptBox["\[ScriptCapitalF]", "~"], "~"], TraditionalForm]],
  ExpressionUUID->"20bf0936-3f85-4cab-831a-7ecccf0986a2"],
 ", which depends on ",
 StyleBox["R",
  FontSlant->"Italic"],
 " indirectly through dependence of the shear strain on R, but this reference \
PK1 stress is not dependent on the angular coordinate. Thus\n\t\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox[
     RowBox[{"d", 
      UnderscriptBox[
       UnderscriptBox["\[ScriptCapitalT]", "~"], "~"]}], 
     RowBox[{"d", " ", "R"}]], "=", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"d", 
        UnderscriptBox[
         UnderscriptBox["\[ScriptCapitalT]", "~"], "~"]}], 
       RowBox[{"d", " ", "\[Epsilon]"}]], " ", 
      FractionBox[
       RowBox[{"d", " ", "\[Epsilon]"}], 
       RowBox[{"d", " ", "R"}]]}], "=", 
     RowBox[{
      FractionBox[
       RowBox[{"d", 
        UnderscriptBox[
         UnderscriptBox["\[ScriptCapitalT]", "~"], "~"]}], 
       RowBox[{"d", " ", "\[Epsilon]"}]], " ", 
      RowBox[{"g", "[", "t", "]"}], 
      RowBox[{
       RowBox[{"\[Xi]", "'"}], "[", "R", "]"}], " "}]}]}], TraditionalForm]],
  ExpressionUUID->"00e686e6-d487-46fd-ad70-74472893b4fb"]
}], "Text",
 CellChangeTimes->{{3.4852240150030146`*^9, 3.485224475403014*^9}, {
  3.4852245349560146`*^9, 3.4852247504980145`*^9}, {3.4852250784330144`*^9, 
  3.4852251766420145`*^9}, {3.4852252223140144`*^9, 3.4852253342350144`*^9}, {
  3.485225374681014*^9, 3.4852253887350144`*^9}, {3.485265416427782*^9, 
  3.485265417285784*^9}, {3.4852655106987476`*^9, 
  3.4852655115879498`*^9}},ExpressionUUID->"85ca4671-663f-4f3e-9ece-\
8c7435ab759b"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Divergence of PK1", "Section",
 CellChangeTimes->{{3.485230197226014*^9, 
  3.4852302019720144`*^9}},ExpressionUUID->"cb233d0a-26c9-47da-b0ae-\
7ae4296427bc"],

Cell[TextData[{
 "The gradient of PK1 stress is\n\t",
 Cell[BoxData[{
  FormBox[
   RowBox[{
    FractionBox[
     RowBox[{"d", 
      UnderscriptBox[
       UnderscriptBox["T", "~"], "~"]}], 
     RowBox[{"d", " ", 
      UnderscriptBox["X", "~"]}]], "=", 
    RowBox[{
     RowBox[{
      SubscriptBox[
       RowBox[{"(", 
        FractionBox[
         RowBox[{"\[PartialD]", " ", 
          UnderscriptBox[
           UnderscriptBox["T", "~"], "~"]}], 
         RowBox[{"\[PartialD]", " ", "R"}]], ")"}], "\[CapitalTheta]"], 
      SubscriptBox[
       StyleBox[
        UnderscriptBox[
         StyleBox["E",
          FontWeight->"Bold",
          FontSlant->"Plain"], "~"],
        FontWeight->"Bold",
        FontSlant->"Plain"], "R"]}], "+", 
     RowBox[{
      FractionBox["1", "R"], 
      SubscriptBox[
       RowBox[{"(", 
        FractionBox[
         RowBox[{"\[PartialD]", " ", 
          UnderscriptBox[
           UnderscriptBox["T", "~"], "~"]}], 
         RowBox[{"\[PartialD]", " ", "\[CapitalTheta]"}]], ")"}], "R"], 
      SubscriptBox[
       StyleBox[
        UnderscriptBox[
         StyleBox["E",
          FontWeight->"Bold",
          FontSlant->"Plain"], "~"],
        FontWeight->"Bold",
        FontSlant->"Plain"], "\[CapitalTheta]"]}]}]}], 
   TraditionalForm], "\[IndentingNewLine]", 
  FormBox[
   RowBox[{"=", 
    RowBox[{
     RowBox[{
      SubscriptBox[
       RowBox[{"(", 
        FractionBox[
         RowBox[{
          RowBox[{"\[PartialD]", " ", 
           UnderscriptBox[
            UnderscriptBox["r", "~"], "~"]}], ".", 
          UnderscriptBox[
           UnderscriptBox["\[ScriptCapitalT]", "~"], "~"], ".", 
          SuperscriptBox[
           UnderscriptBox[
            UnderscriptBox["q", "~"], "~"], "T"]}], 
         RowBox[{"\[PartialD]", " ", "R"}]], ")"}], "\[CapitalTheta]"], 
      SubscriptBox[
       StyleBox[
        UnderscriptBox[
         StyleBox["E",
          FontWeight->"Bold",
          FontSlant->"Plain"], "~"],
        FontWeight->"Bold",
        FontSlant->"Plain"], "R"]}], "+", 
     RowBox[{
      FractionBox["1", "R"], 
      SubscriptBox[
       RowBox[{"(", 
        FractionBox[
         RowBox[{
          RowBox[{"\[PartialD]", " ", 
           UnderscriptBox[
            UnderscriptBox["r", "~"], "~"]}], ".", 
          UnderscriptBox[
           UnderscriptBox["\[ScriptCapitalT]", "~"], "~"], ".", 
          SuperscriptBox[
           UnderscriptBox[
            UnderscriptBox["q", "~"], "~"], "T"]}], 
         RowBox[{"\[PartialD]", " ", "\[CapitalTheta]"}]], ")"}], "R"], 
      SubscriptBox[
       StyleBox[
        UnderscriptBox[
         StyleBox["E",
          FontWeight->"Bold",
          FontSlant->"Plain"], "~"],
        FontWeight->"Bold",
        FontSlant->"Plain"], "\[CapitalTheta]"]}]}]}], 
   TraditionalForm], "\[IndentingNewLine]", 
  FormBox[
   RowBox[{"=", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"g", "[", "t", "]"}], 
         RowBox[{
          RowBox[{"h", "'"}], "[", "R", "]"}], 
         RowBox[{
          UnderscriptBox[
           UnderscriptBox["A", "~"], "~"], ".", 
          UnderscriptBox[
           UnderscriptBox["r", "~"], "~"], ".", 
          UnderscriptBox[
           UnderscriptBox["\[ScriptCapitalT]", "~"], "~"], ".", 
          SuperscriptBox[
           UnderscriptBox[
            UnderscriptBox["q", "~"], "~"], "T"]}]}], "+", 
        RowBox[{
         RowBox[{"g", "[", "t", "]"}], 
         RowBox[{
          RowBox[{"\[Xi]", "'"}], "[", "R", "]"}], "   ", 
         RowBox[{
          UnderscriptBox[
           UnderscriptBox["r", "~"], "~"], ".", 
          FractionBox[
           RowBox[{"d", 
            UnderscriptBox[
             UnderscriptBox["\[ScriptCapitalT]", "~"], "~"]}], 
           RowBox[{"d", " ", "\[Epsilon]"}]], " ", ".", 
          SuperscriptBox[
           UnderscriptBox[
            UnderscriptBox["q", "~"], "~"], "T"]}]}]}], ")"}], 
      SubscriptBox[
       StyleBox[
        UnderscriptBox[
         StyleBox["E",
          FontWeight->"Bold",
          FontSlant->"Plain"], "~"],
        FontWeight->"Bold",
        FontSlant->"Plain"], "R"]}], "+", 
     RowBox[{
      FractionBox["1", "R"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         UnderscriptBox[
          UnderscriptBox["A", "~"], "~"], ".", 
         UnderscriptBox[
          UnderscriptBox["r", "~"], "~"], ".", 
         UnderscriptBox[
          UnderscriptBox["\[ScriptCapitalT]", "~"], "~"], ".", 
         SuperscriptBox[
          UnderscriptBox[
           UnderscriptBox["q", "~"], "~"], "T"]}], "+", 
        RowBox[{
         UnderscriptBox[
          UnderscriptBox["r", "~"], "~"], ".", 
         UnderscriptBox[
          UnderscriptBox["\[ScriptCapitalT]", "~"], "~"], ".", 
         SuperscriptBox[
          UnderscriptBox[
           UnderscriptBox["q", "~"], "~"], "T"], ".", 
         SuperscriptBox[
          UnderscriptBox[
           UnderscriptBox["A", "~"], "~"], "T"]}]}], ")"}], 
      SubscriptBox[
       StyleBox[
        UnderscriptBox[
         StyleBox["E",
          FontWeight->"Bold",
          FontSlant->"Plain"], "~"],
        FontWeight->"Bold",
        FontSlant->"Plain"], "\[CapitalTheta]"]}]}]}], 
   TraditionalForm], "\[IndentingNewLine]", 
  FormBox[
   RowBox[{"=", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"g", "[", "t", "]"}], 
         RowBox[{
          RowBox[{"h", "'"}], "[", "R", "]"}], 
         RowBox[{
          UnderscriptBox[
           UnderscriptBox["A", "~"], "~"], ".", 
          UnderscriptBox[
           UnderscriptBox["T", "~"], "~"]}]}], "+", 
        RowBox[{
         RowBox[{"g", "[", "t", "]"}], 
         RowBox[{
          RowBox[{"\[Xi]", "'"}], "[", "R", "]"}], "   ", 
         RowBox[{
          UnderscriptBox[
           UnderscriptBox["r", "~"], "~"], ".", 
          FractionBox[
           RowBox[{"d", 
            UnderscriptBox[
             UnderscriptBox["\[ScriptCapitalT]", "~"], "~"]}], 
           RowBox[{"d", " ", "\[Epsilon]"}]], " ", ".", 
          SuperscriptBox[
           UnderscriptBox[
            UnderscriptBox["q", "~"], "~"], "T"]}]}]}], ")"}], 
      SubscriptBox[
       StyleBox[
        UnderscriptBox[
         StyleBox["E",
          FontWeight->"Bold",
          FontSlant->"Plain"], "~"],
        FontWeight->"Bold",
        FontSlant->"Plain"], "R"]}], "+", 
     RowBox[{
      FractionBox["1", "R"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         UnderscriptBox[
          UnderscriptBox["A", "~"], "~"], ".", 
         UnderscriptBox[
          UnderscriptBox["T", "~"], "~"]}], "+", 
        RowBox[{
         UnderscriptBox[
          UnderscriptBox["T", "~"], "~"], ".", 
         SuperscriptBox[
          UnderscriptBox[
           UnderscriptBox["A", "~"], "~"], "T"]}]}], ")"}], 
      SubscriptBox[
       StyleBox[
        UnderscriptBox[
         StyleBox["E",
          FontWeight->"Bold",
          FontSlant->"Plain"], "~"],
        FontWeight->"Bold",
        FontSlant->"Plain"], "\[CapitalTheta]"]}]}]}], TraditionalForm]}],
  ExpressionUUID->"2818a26a-a830-45d7-a798-1cf7a34a72fc"]
}], "Text",
 CellChangeTimes->{
  3.7507873237340555`*^9},ExpressionUUID->"29f18a2b-0007-49cf-a95d-\
5caa75b1c845"],

Cell[TextData[{
 "The reference divergence of PK1 stress is then\n\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[Rho]", "0"], "(", 
     RowBox[{
      UnderscriptBox["a", "~"], "-", 
      UnderscriptBox["b", "~"]}], ")"}], "=", 
    RowBox[{
     RowBox[{"DIV", "(", 
      UnderscriptBox[
       UnderscriptBox["T", "~"], "~"], ")"}], "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"g", "[", "t", "]"}], 
         RowBox[{
          RowBox[{"h", "'"}], "[", "R", "]"}], 
         RowBox[{
          UnderscriptBox[
           UnderscriptBox["A", "~"], "~"], ".", 
          UnderscriptBox[
           UnderscriptBox["T", "~"], "~"], ".", 
          SubscriptBox[
           StyleBox[
            UnderscriptBox[
             StyleBox["E",
              FontWeight->"Bold",
              FontSlant->"Plain"], "~"],
            FontWeight->"Bold",
            FontSlant->"Plain"], "R"]}]}], "+", 
        RowBox[{
         RowBox[{"g", "[", "t", "]"}], 
         RowBox[{
          RowBox[{"\[Xi]", "'"}], "[", "R", "]"}], "   ", 
         RowBox[{
          UnderscriptBox[
           UnderscriptBox["r", "~"], "~"], ".", 
          FractionBox[
           RowBox[{"d", 
            UnderscriptBox[
             UnderscriptBox["\[ScriptCapitalT]", "~"], "~"]}], 
           RowBox[{"d", " ", "\[Epsilon]"}]], " ", ".", 
          SubscriptBox[
           StyleBox[
            UnderscriptBox[
             StyleBox["E",
              FontWeight->"Bold",
              FontSlant->"Plain"], "~"],
            FontWeight->"Bold",
            FontSlant->"Plain"], "1"]}]}]}], ")"}], "+", 
      RowBox[{
       FractionBox["1", "R"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          UnderscriptBox[
           UnderscriptBox["A", "~"], "~"], ".", 
          UnderscriptBox[
           UnderscriptBox["T", "~"], "~"], ".", 
          SubscriptBox[
           StyleBox[
            UnderscriptBox[
             StyleBox["E",
              FontWeight->"Bold",
              FontSlant->"Plain"], "~"],
            FontWeight->"Bold",
            FontSlant->"Plain"], "\[CapitalTheta]"]}], "+", 
         RowBox[{
          UnderscriptBox[
           UnderscriptBox["T", "~"], "~"], ".", 
          SubscriptBox[
           StyleBox[
            UnderscriptBox[
             StyleBox["E",
              FontWeight->"Bold",
              FontSlant->"Plain"], "~"],
            FontWeight->"Bold",
            FontSlant->"Plain"], "R"]}]}], ")"}]}]}]}]}], TraditionalForm]],
  ExpressionUUID->"29562f68-cf6d-4ae4-b2a3-a0f83ae94d2d"]
}], "Text",
 CellChangeTimes->{{3.485224792891014*^9, 3.4852249020450144`*^9}, {
   3.4852249605910144`*^9, 3.485225018719014*^9}, {3.4852252003730145`*^9, 
   3.4852252081070147`*^9}, {3.4852254154300146`*^9, 
   3.4852254770910144`*^9}, {3.4852255107370143`*^9, 
   3.4852256071000147`*^9}, {3.4852257504580145`*^9, 3.485225843016014*^9}, {
   3.4852258904150143`*^9, 3.4852258985510144`*^9}, {3.4852259335580144`*^9, 
   3.4852259796680145`*^9}, {3.485226072372014*^9, 3.4852262616390142`*^9}, {
   3.4852263022180147`*^9, 3.4852263108130145`*^9}, 3.4852264112960143`*^9, {
   3.4852264630640144`*^9, 3.485226538016014*^9}, {3.485226628207014*^9, 
   3.485226881554014*^9}, {3.4852269483150144`*^9, 3.4852269484490147`*^9}, {
   3.4852270206800146`*^9, 3.4852270208290143`*^9}, {3.4852270803640146`*^9, 
   3.4852271281140146`*^9}, {3.4852271761550145`*^9, 
   3.4852272023100147`*^9}, {3.4852273803990145`*^9, 
   3.4852274092360144`*^9}, {3.4852274494630146`*^9, 
   3.4852275279680147`*^9}, {3.4852276402700143`*^9, 3.485227668068014*^9}, {
   3.485233040521014*^9, 3.4852331340070143`*^9}, {3.485265723873122*^9, 
   3.4852657459939613`*^9}, {3.485265776211214*^9, 3.4852657853060303`*^9}, {
   3.4852663132421575`*^9, 3.4852663395438037`*^9}, {3.4852664308819637`*^9, 
   3.4852664614112177`*^9}, {3.7507873175470076`*^9, 
   3.750787344935265*^9}},ExpressionUUID->"ec9e21c5-ea22-4bfa-9b6b-\
dcfbc9686a0d"],

Cell[TextData[{
 "The spatial radial component is\n\t",
 Cell[BoxData[{
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[Rho]", "0"], "(", 
     RowBox[{
      SubscriptBox["a", "r"], "-", 
      SubscriptBox["b", "r"]}], ")"}], "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"g", "[", "t", "]"}]}], 
        RowBox[{
         RowBox[{"h", "'"}], "[", "R", "]"}], 
        RowBox[{
         SubscriptBox[
          StyleBox[
           UnderscriptBox[
            StyleBox["e",
             FontSlant->"Plain"], "~"],
           FontWeight->"Bold",
           FontSlant->"Plain"], "\[CurlyTheta]"], ".", 
         UnderscriptBox[
          UnderscriptBox["T", "~"], "~"], ".", 
         SubscriptBox[
          StyleBox[
           UnderscriptBox[
            StyleBox["E",
             FontWeight->"Bold",
             FontSlant->"Plain"], "~"],
           FontWeight->"Bold",
           FontSlant->"Plain"], "R"]}]}], "+", 
       RowBox[{
        RowBox[{"g", "[", "t", "]"}], 
        RowBox[{
         RowBox[{"\[Xi]", "'"}], "[", "R", "]"}], "  ", 
        RowBox[{
         SubscriptBox[
          StyleBox[
           UnderscriptBox[
            StyleBox["E",
             FontWeight->"Bold",
             FontSlant->"Plain"], "~"],
           FontWeight->"Bold",
           FontSlant->"Plain"], "1"], ".", 
         FractionBox[
          RowBox[{"d", 
           UnderscriptBox[
            UnderscriptBox["\[ScriptCapitalT]", "~"], "~"]}], 
          RowBox[{"d", " ", "\[Epsilon]"}]], " ", ".", 
         SubscriptBox[
          StyleBox[
           UnderscriptBox[
            StyleBox["E",
             FontWeight->"Bold",
             FontSlant->"Plain"], "~"],
           FontWeight->"Bold",
           FontSlant->"Plain"], "1"]}]}]}], ")"}], "+", 
     RowBox[{
      FractionBox["1", "R"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          SubscriptBox[
           StyleBox[
            UnderscriptBox[
             StyleBox["e",
              FontSlant->"Plain"], "~"],
            FontWeight->"Bold",
            FontSlant->"Plain"], "\[CurlyTheta]"], ".", 
          UnderscriptBox[
           UnderscriptBox["T", "~"], "~"], ".", 
          SubscriptBox[
           StyleBox[
            UnderscriptBox[
             StyleBox["E",
              FontWeight->"Bold",
              FontSlant->"Plain"], "~"],
            FontWeight->"Bold",
            FontSlant->"Plain"], "\[CapitalTheta]"]}]}], "+", 
        RowBox[{
         SubscriptBox[
          StyleBox[
           UnderscriptBox[
            StyleBox["e",
             FontSlant->"Plain"], "~"],
           FontWeight->"Bold",
           FontSlant->"Plain"], "r"], ".", 
         UnderscriptBox[
          UnderscriptBox["T", "~"], "~"], ".", 
         SubscriptBox[
          StyleBox[
           UnderscriptBox[
            StyleBox["E",
             FontWeight->"Bold",
             FontSlant->"Plain"], "~"],
           FontWeight->"Bold",
           FontSlant->"Plain"], "R"]}]}], ")"}]}]}]}], 
   TraditionalForm], "\[IndentingNewLine]", 
  FormBox[
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"g", "[", "t", "]"}]}], 
        RowBox[{
         RowBox[{"h", "'"}], "[", "R", "]"}], 
        SubscriptBox["\[ScriptCapitalT]", "21"]}], "+", 
       RowBox[{
        RowBox[{"g", "[", "t", "]"}], 
        RowBox[{
         RowBox[{"\[Xi]", "'"}], "[", "R", "]"}], "  ", 
        FractionBox[
         RowBox[{"d", " ", 
          SubscriptBox["\[ScriptCapitalT]", "11"]}], 
         RowBox[{"d", " ", "\[Epsilon]"}]]}]}], ")"}], "+", 
     RowBox[{
      FractionBox["1", "R"], 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[ScriptCapitalT]", "11"], "-", 
        SubscriptBox["\[ScriptCapitalT]", "22"]}], ")"}]}]}]}], 
   TraditionalForm], "\[IndentingNewLine]", 
  FormBox[
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"\[Xi]", "'"}], "[", "R", "]"}], "  ", 
         FractionBox[
          RowBox[{"d", " ", 
           SubscriptBox["\[ScriptCapitalT]", "11"]}], 
          RowBox[{"d", " ", "\[Epsilon]"}]]}], "-", 
        RowBox[{
         RowBox[{
          RowBox[{"h", "'"}], "[", "R", "]"}], 
         SubscriptBox["\[ScriptCapitalT]", "21"]}]}], ")"}], 
      RowBox[{"g", "[", "t", "]"}]}], "+", 
     RowBox[{
      FractionBox["1", "R"], 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[ScriptCapitalT]", "11"], "-", 
        SubscriptBox["\[ScriptCapitalT]", "22"]}], ")"}]}]}]}], 
   TraditionalForm]}],ExpressionUUID->"7d96e7c4-371d-4c46-ab8c-0d902cf9e96a"]
}], "Text",
 CellChangeTimes->{{3.750787351298258*^9, 
  3.7507873591677384`*^9}},ExpressionUUID->"1413783c-5184-4b80-a465-\
12693d1a4cf2"],

Cell[TextData[{
 "The spatial tangential component is\n\t",
 Cell[BoxData[{
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[Rho]", "0"], "(", 
     RowBox[{
      SubscriptBox["a", "\[CurlyTheta]"], "-", 
      SubscriptBox["b", "\[CurlyTheta]"]}], ")"}], "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"g", "[", "t", "]"}], 
        RowBox[{
         RowBox[{"h", "'"}], "[", "R", "]"}], 
        RowBox[{
         SubscriptBox[
          StyleBox[
           UnderscriptBox[
            StyleBox["e",
             FontSlant->"Plain"], "~"],
           FontWeight->"Bold",
           FontSlant->"Plain"], "r"], ".", 
         UnderscriptBox[
          UnderscriptBox["T", "~"], "~"], ".", 
         SubscriptBox[
          StyleBox[
           UnderscriptBox[
            StyleBox["E",
             FontWeight->"Bold",
             FontSlant->"Plain"], "~"],
           FontWeight->"Bold",
           FontSlant->"Plain"], "R"]}]}], "+", 
       RowBox[{
        RowBox[{"g", "[", "t", "]"}], 
        RowBox[{
         RowBox[{"\[Xi]", "'"}], "[", "R", "]"}], "  ", 
        RowBox[{
         SubscriptBox[
          StyleBox[
           UnderscriptBox[
            StyleBox["E",
             FontWeight->"Bold",
             FontSlant->"Plain"], "~"],
           FontWeight->"Bold",
           FontSlant->"Plain"], "2"], ".", 
         FractionBox[
          RowBox[{"d", 
           UnderscriptBox[
            UnderscriptBox["\[ScriptCapitalT]", "~"], "~"]}], 
          RowBox[{"d", " ", "\[Epsilon]"}]], " ", ".", 
         SubscriptBox[
          StyleBox[
           UnderscriptBox[
            StyleBox["E",
             FontWeight->"Bold",
             FontSlant->"Plain"], "~"],
           FontWeight->"Bold",
           FontSlant->"Plain"], "1"]}]}]}], ")"}], "+", 
     RowBox[{
      FractionBox["1", "R"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox[
          StyleBox[
           UnderscriptBox[
            StyleBox["e",
             FontSlant->"Plain"], "~"],
           FontWeight->"Bold",
           FontSlant->"Plain"], "r"], ".", 
         UnderscriptBox[
          UnderscriptBox["T", "~"], "~"], ".", 
         SubscriptBox[
          StyleBox[
           UnderscriptBox[
            StyleBox["E",
             FontWeight->"Bold",
             FontSlant->"Plain"], "~"],
           FontWeight->"Bold",
           FontSlant->"Plain"], "\[CapitalTheta]"]}], "+", 
        RowBox[{
         SubscriptBox[
          StyleBox[
           UnderscriptBox[
            StyleBox["e",
             FontSlant->"Plain"], "~"],
           FontWeight->"Bold",
           FontSlant->"Plain"], "\[CurlyTheta]"], ".", 
         UnderscriptBox[
          UnderscriptBox["T", "~"], "~"], ".", 
         SubscriptBox[
          StyleBox[
           UnderscriptBox[
            StyleBox["E",
             FontWeight->"Bold",
             FontSlant->"Plain"], "~"],
           FontWeight->"Bold",
           FontSlant->"Plain"], "R"]}]}], ")"}]}]}]}], 
   TraditionalForm], "\[IndentingNewLine]", 
  FormBox[
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"g", "[", "t", "]"}], 
        RowBox[{
         RowBox[{"h", "'"}], "[", "R", "]"}], 
        SubscriptBox["\[ScriptCapitalT]", "11"]}], "+", 
       RowBox[{
        RowBox[{"g", "[", "t", "]"}], 
        RowBox[{
         RowBox[{"\[Xi]", "'"}], "[", "R", "]"}], "  ", 
        FractionBox[
         RowBox[{"d", " ", 
          SubscriptBox["\[ScriptCapitalT]", "21"]}], 
         RowBox[{"d", " ", "\[Epsilon]"}]]}]}], ")"}], "+", 
     RowBox[{
      FractionBox["1", "R"], 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[ScriptCapitalT]", "12"], "+", 
        SubscriptBox["\[ScriptCapitalT]", "21"]}], ")"}]}]}]}], 
   TraditionalForm], "\[IndentingNewLine]", 
  FormBox[
   RowBox[{"=", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"\[Xi]", "'"}], "[", "R", "]"}], "  ", 
         FractionBox[
          RowBox[{"d", " ", 
           SubscriptBox["\[ScriptCapitalT]", "21"]}], 
          RowBox[{"d", " ", "\[Epsilon]"}]]}], "+", 
        RowBox[{
         RowBox[{
          RowBox[{"h", "'"}], "[", "R", "]"}], 
         SubscriptBox["\[ScriptCapitalT]", "11"]}]}], ")"}], 
      RowBox[{"g", "[", "t", "]"}]}], "+", 
     RowBox[{
      FractionBox["1", "R"], 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[ScriptCapitalT]", "12"], "+", 
        SubscriptBox["\[ScriptCapitalT]", "21"]}], ")"}]}]}]}], 
   TraditionalForm]}],ExpressionUUID->"27bb73ec-485f-40fe-b415-41cda5aba152"],
 "\n\t\nNOTE KEY ADVANTAGE:   This result is expressed in terms of the \
CARTESIAN components of the PK1 stress corresponding to a homogeneous pure \
shear.  That means you only need to evaluate the constitutive model for that \
special case. "
}], "Text",
 CellChangeTimes->{
  3.750787363528351*^9},ExpressionUUID->"5d3ce0e2-1682-49bd-bf1a-\
c9bea912ad01"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Finding body force", "Section",
 CellChangeTimes->{{3.4852301733810143`*^9, 
  3.485230176016014*^9}},ExpressionUUID->"6d194eca-5f7f-4735-a91c-\
b924df3d2a00"],

Cell[TextData[{
 "Recall that  \n\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderscriptBox["v", "~"], "=", 
    RowBox[{"R", " ", "\[Omega]", " ", 
     SubscriptBox[
      StyleBox[
       UnderscriptBox[
        StyleBox["e",
         FontSlant->"Plain"], "~"],
       FontWeight->"Bold",
       FontSlant->"Italic"], "\[CurlyTheta]"]}]}], TraditionalForm]],
  ExpressionUUID->"2aab9236-2982-4573-88d0-da347db8a861"],
 ",  \n\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderscriptBox["a", "~"], "=", 
    RowBox[{
     RowBox[{"R", " ", 
      OverscriptBox["\[Omega]", "."], " ", 
      SubscriptBox[
       StyleBox[
        UnderscriptBox[
         StyleBox["e",
          FontSlant->"Plain"], "~"],
        FontWeight->"Bold",
        FontSlant->"Italic"], "\[CurlyTheta]"]}], "-", 
     RowBox[{"R", " ", 
      SuperscriptBox["\[Omega]", "2"], " ", 
      SubscriptBox[
       StyleBox[
        UnderscriptBox[
         StyleBox["e",
          FontSlant->"Plain"], "~"],
        FontWeight->"Bold",
        FontSlant->"Italic"], "r"]}]}]}], TraditionalForm]],ExpressionUUID->
  "e35e6d27-6c52-4cf7-8044-fdaf663dd799"],
 "\nwhere\n\twhere \t\[Omega] =g'[t] h[R]\n\t\t",
 Cell[BoxData[
  FormBox[
   OverscriptBox["\[Omega]", "."], TraditionalForm]],ExpressionUUID->
  "c917225b-7950-4875-b1bf-adbaa29c2957"],
 " =g''[t]  h[R]"
}], "Text",
 CellChangeTimes->{{3.4852291158130145`*^9, 3.4852291250770144`*^9}, {
  3.4852304972340145`*^9, 
  3.4852305010180144`*^9}},ExpressionUUID->"7f85de26-a743-45e4-838e-\
87ea77de3e94"],

Cell[TextData[{
 "Thus\n\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["b", "r"], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "R"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"g", "'"}], "[", "t", "]"}], " ", 
         RowBox[{"h", "[", "R", "]"}]}], ")"}], "2"]}], "-", 
     RowBox[{
      FractionBox["1", 
       SubscriptBox["\[Rho]", "0"]], 
      RowBox[{"{", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"\[Xi]", "'"}], "[", "R", "]"}], "  ", 
            FractionBox[
             RowBox[{"d", " ", 
              SubscriptBox["\[ScriptCapitalT]", "11"]}], 
             RowBox[{"d", " ", "\[Epsilon]"}]]}], "-", 
           RowBox[{
            RowBox[{
             RowBox[{"h", "'"}], "[", "R", "]"}], 
            SubscriptBox["\[ScriptCapitalT]", "21"]}]}], ")"}], 
         RowBox[{"g", "[", "t", "]"}]}], "+", 
        RowBox[{
         FractionBox["1", "R"], 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[ScriptCapitalT]", "11"], "-", 
           SubscriptBox["\[ScriptCapitalT]", "22"]}], ")"}]}]}], "}"}]}]}]}], 
   TraditionalForm]],ExpressionUUID->"f312960a-4ea6-482a-9274-6034349454b1"],
 "\n\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["b", "\[CurlyTheta]"], "=", 
    RowBox[{
     RowBox[{"R", " ", 
      RowBox[{
       RowBox[{"g", "''"}], "[", "t", "]"}], " ", 
      RowBox[{"h", "[", "R", "]"}]}], "-", 
     RowBox[{
      FractionBox["1", 
       SubscriptBox["\[Rho]", "0"]], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"\[Xi]", "'"}], "[", "R", "]"}], "  ", 
            FractionBox[
             RowBox[{"d", " ", 
              SubscriptBox["\[ScriptCapitalT]", "21"]}], 
             RowBox[{"d", " ", "\[Epsilon]"}]]}], "+", 
           RowBox[{
            RowBox[{
             RowBox[{"h", "'"}], "[", "R", "]"}], 
            SubscriptBox["\[ScriptCapitalT]", "11"]}]}], ")"}], 
         RowBox[{"g", "[", "t", "]"}]}], "+", 
        RowBox[{
         FractionBox["1", "R"], 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[ScriptCapitalT]", "12"], "+", 
           SubscriptBox["\[ScriptCapitalT]", "21"]}], ")"}]}]}], "}"}]}]}]}], 
   TraditionalForm]],ExpressionUUID->"57bcaaff-70a3-4988-ac1c-53715187f07d"]
}], "Text",
 CellChangeTimes->{{3.485229133679014*^9, 3.4852293749370146`*^9}, {
  3.4852664192911434`*^9, 
  3.4852664682128296`*^9}},ExpressionUUID->"24eb9f75-eb06-4d3e-96ec-\
7b2237f9458e"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Algorithm", "Section",
 CellChangeTimes->{{3.485233166023014*^9, 
  3.4852331674510145`*^9}},ExpressionUUID->"3b5cd0a9-7aa3-498d-bb47-\
312b3ea62cae"],

Cell[TextData[{
 "Procedure:\n\t1. Select g[t] and h[R] functions\n\t\n\t2. Select an \
isotropic elastic constitutive model\n\t\t Work out the analytical solution \
for the Cartesian components of the PK1 stress,\n\t\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderscriptBox[
     UnderscriptBox["\[ScriptCapitalT]", "~"], "~"], "=", 
    RowBox[{"(", GridBox[{
       {
        SubscriptBox["\[ScriptCapitalT]", "11"], 
        SubscriptBox["\[ScriptCapitalT]", "12"], 
        SubscriptBox["\[ScriptCapitalT]", "13"]},
       {
        SubscriptBox["\[ScriptCapitalT]", "21"], 
        SubscriptBox["\[ScriptCapitalT]", "22"], 
        SubscriptBox["\[ScriptCapitalT]", "23"]},
       {
        SubscriptBox["\[ScriptCapitalT]", "31"], 
        SubscriptBox["\[ScriptCapitalT]", "32"], 
        SubscriptBox["\[ScriptCapitalT]", "33"]}
      }], ")"}]}], TraditionalForm]],ExpressionUUID->
  "a53d2fe0-bd0f-4724-84b6-f90b83864007"],
 "\n\t\tcorresponding to a homogeneous deformation with deformation gradient\n\
\t\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderscriptBox[
     UnderscriptBox["\[ScriptCapitalF]", "~"], "~"], " ", "=", 
    RowBox[{"(", GridBox[{
       {"1", "0", "0"},
       {
        RowBox[{"2", "\[Epsilon]"}], "1", "0"},
       {"0", "0", "1"}
      }], ")"}]}], TraditionalForm]],ExpressionUUID->
  "128f97ea-72a2-49bc-9376-96533814f33a"],
 "\n\t\t\n\t3. Substitute the result into the above formulas for ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "r"], TraditionalForm]],ExpressionUUID->
  "82a0ec2b-63d9-4d04-b438-bed4ae8f71fe"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "\[CurlyTheta]"], TraditionalForm]],ExpressionUUID->
  "e29da293-33e5-45a6-a67a-685de453325e"],
 "  and evaluate the result using\n\t\t",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Epsilon]", "=", 
    RowBox[{
     FractionBox["1", "2"], 
     RowBox[{"g", "[", "t", "]"}], " ", "R", " ", 
     RowBox[{
      RowBox[{"h", "'"}], "[", "R", "]"}], " "}]}], TraditionalForm]],
  ExpressionUUID->"0c4832e9-ab65-42d3-a1df-d12544aa393d"],
 " =",
 Cell[BoxData[
  FormBox[
   RowBox[{"     ", 
    RowBox[{
     RowBox[{"g", "[", "t", "]"}], " ", 
     RowBox[{"\[Xi]", "[", "R", "]"}], " "}]}], TraditionalForm]],
  ExpressionUUID->"17390243-9229-449d-9bff-40cb5a5df7e1"],
 "\n\t\tThis will give for ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "r"], TraditionalForm]],ExpressionUUID->
  "aea0bdaa-0324-4e35-bafe-45e6aa0fe155"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "\[CurlyTheta]"], TraditionalForm]],ExpressionUUID->
  "d60895c5-2d96-4bc6-83d8-9dbfc1a71a8c"],
 "  as functions of time and radius.\n\t\t\n\t4. Evaluate the body force \
vector by\n\t\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderscriptBox[
     StyleBox["b",
      FontWeight->"Bold",
      FontSlant->"Plain"], "~"], "=", 
    RowBox[{
     RowBox[{
      SubscriptBox["b", "r"], 
      SubscriptBox[
       UnderscriptBox[
        StyleBox["e",
         FontWeight->"Bold",
         FontSlant->"Plain"], "~"], "r"]}], "+", 
     RowBox[{
      SubscriptBox["b", "\[CurlyTheta]"], 
      SubscriptBox[
       UnderscriptBox[
        StyleBox["e",
         FontWeight->"Bold",
         FontSlant->"Plain"], "~"], "\[CurlyTheta]"]}]}]}], TraditionalForm]],
  ExpressionUUID->"c590955c-717f-4ae7-8409-8866aa8ae006"],
 "\n\t\tIf Cartesian component are desired, evaluate this body force vector \
using\n\t\t\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     UnderscriptBox[
      StyleBox["e",
       FontWeight->"Bold",
       FontSlant->"Plain"], "~"], "r"], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Cos", "[", "\[CurlyTheta]", "]"}], 
      SubscriptBox[
       UnderscriptBox[
        StyleBox["E",
         FontWeight->"Bold",
         FontSlant->"Plain"], "~"], "1"]}], "+", 
     RowBox[{
      RowBox[{"Sin", "[", "\[CurlyTheta]", "]"}], 
      SubscriptBox[
       UnderscriptBox[
        StyleBox["E",
         FontWeight->"Bold",
         FontSlant->"Plain"], "~"], "2"]}]}]}], TraditionalForm]],
  ExpressionUUID->"f83d5033-ebdb-4323-b7d7-0f70cddfa5ea"],
 "\n\t\t\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     UnderscriptBox[
      StyleBox["e",
       FontWeight->"Bold",
       FontSlant->"Plain"], "~"], "\[CurlyTheta]"], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Sin", "[", "\[CurlyTheta]", "]"}]}], 
      SubscriptBox[
       UnderscriptBox[
        StyleBox["E",
         FontWeight->"Bold",
         FontSlant->"Plain"], "~"], "1"]}], "+", 
     RowBox[{
      RowBox[{"Cos", "[", "\[CurlyTheta]", "]"}], 
      SubscriptBox[
       UnderscriptBox[
        StyleBox["E",
         FontWeight->"Bold",
         FontSlant->"Plain"], "~"], "2"]}]}]}], TraditionalForm]],
  ExpressionUUID->"126ec1a6-64b8-4137-b9ea-c3c188d28dd7"],
 "\n\t\twhere\n\t\t\t\[CurlyTheta] = \[CapitalTheta] + g[t] h[R]"
}], "Text",
 CellChangeTimes->{{3.4852294374700146`*^9, 3.485229710641014*^9}, {
  3.4852297446950145`*^9, 3.4852299174340143`*^9}, {3.4852299526180143`*^9, 
  3.4852300338620143`*^9}, {3.485230080516014*^9, 3.4852301423740144`*^9}, {
  3.4852305128660145`*^9, 3.4852308775430145`*^9}, {3.4852310252060146`*^9, 
  3.4852310995530148`*^9}, {3.4852328020530148`*^9, 3.4852328303530145`*^9}, {
  3.4852328661820145`*^9, 3.4852329059110146`*^9}, {3.4852665763210196`*^9, 
  3.4852665813598285`*^9}, {3.4852666276607094`*^9, 
  3.4852666322471175`*^9}},ExpressionUUID->"0b78b761-4063-42d1-8901-\
1fb0adb5be2a"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Specific study", "Section",
 CellChangeTimes->{{3.4852302801050143`*^9, 3.4852302863410144`*^9}, {
  3.4852311181770144`*^9, 
  3.4852311210600147`*^9}},ExpressionUUID->"3ecbd097-7059-469b-8f60-\
b2248560f744"],

Cell[TextData[{
 "The above sections provide all of the analytical work phrased in terms of \
generic functions g[t], h[R], and whatever the isotropic elastic constitutive \
model predicts for the ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[ScriptCapitalT]", "11"], "(", "\[Epsilon]", ")"}], ",", 
    " ", 
    RowBox[{
     SubscriptBox["\[ScriptCapitalT]", "22"], "(", "\[Epsilon]", ")"}]}], 
   TraditionalForm]],ExpressionUUID->"6f634728-0abf-4c40-a4ac-7615ca94ab93"],
 ", and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[ScriptCapitalT]", "21"], TraditionalForm]],ExpressionUUID->
  "2b24f2b6-4322-4161-be09-72d6999f44fb"],
 "(\[Epsilon]) PK1 stress components in response to a deformation gradient ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", GridBox[{
      {"1", "0", "0"},
      {
       RowBox[{"2", "\[Epsilon]"}], "1", "0"},
      {"0", "0", "1"}
     }], ")"}], TraditionalForm]],ExpressionUUID->
  "8f3e1f75-8843-4b33-aef4-fc71d39dde74"],
 ".  In other words, the body force is determined at this point entirely in \
terms of these five user-controllable functions.  This \
\[OpenCurlyDoubleQuote]specific study\[CloseCurlyDoubleQuote] section now \
makes specific choices for the g[t] and h[R] functions in order to generate \
graphics of the MMS deformation.  "
}], "Text",
 CellChangeTimes->{{3.7507805819693174`*^9, 3.7507806581531754`*^9}, {
  3.7507806885614853`*^9, 
  3.750780866666404*^9}},ExpressionUUID->"fd2cf5c2-a341-4c8c-ac5e-\
ce6377e40f4c"],

Cell[BoxData[
 RowBox[{"ClearAll", "[", "\"\<Global`*\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.4852187124060144`*^9, 
  3.4852187250770144`*^9}},ExpressionUUID->"404fec1d-d741-4eb7-abb9-\
98211f86182d"],

Cell["\<\
Step 1: select  formula for time and radial dependence of the rotation angle\
\>", "Text",
 CellChangeTimes->{{3.485232496990014*^9, 3.4852325372130146`*^9}, 
   3.4852329113860145`*^9},ExpressionUUID->"ced80c35-1eeb-4e4f-8f0e-\
1e7a6365ff53"],

Cell[BoxData[{
 RowBox[{"g", "=."}], "\[IndentingNewLine]", 
 RowBox[{"h", "=."}]}], "Input",
 CellChangeTimes->{{3.4852329186620145`*^9, 
  3.4852329227540145`*^9}},ExpressionUUID->"ee78720f-2005-498c-afcf-\
45120f26f8af"],

Cell["Set g[t] such that g=1 when t=tref. ", "Text",
 CellChangeTimes->{{3.4852547070700145`*^9, 
  3.4852547435580144`*^9}},ExpressionUUID->"5a467ce7-4214-4234-b533-\
842484395f68"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"tref", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g", "[", "t_", "]"}], ":=", 
  FractionBox["t", "tref"]}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"g", "[", "t", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "tref"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.4852547473530145`*^9, 3.4852547632940145`*^9}, {
  3.4852704909606953`*^9, 
  3.485270491740697*^9}},ExpressionUUID->"05a2c4bd-d489-46e6-849b-\
0eb4f554bb5d"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"tref", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g", "[", "t_", "]"}], ":=", 
  RowBox[{"Sin", "[", 
   RowBox[{"\[Pi]", " ", 
    FractionBox["t", "tref"]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"g", "[", "t", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "tref"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.4852704313217907`*^9, 
  3.4852704820218797`*^9}},ExpressionUUID->"6d70bffb-f1c2-4fc9-990b-\
f82f2cdbc8a4"],

Cell[BoxData[
 RowBox[{"\[Alpha]", "=", 
  RowBox[{
   RowBox[{"g", "[", "t", "]"}], 
   RowBox[{"h", "[", "R", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4852325431290145`*^9, 
  3.485232550061014*^9}},ExpressionUUID->"175df049-18fc-4d10-ac1c-\
b1f065d00cc6"],

Cell[TextData[{
 "Define the radial value at the center of the ring:\n\t",
 Cell[BoxData[
  FormBox[
   RowBox[{"c", "=", 
    RowBox[{
     FractionBox["1", "2"], 
     RowBox[{"(", 
      RowBox[{"a", "+", "b"}], ")"}]}]}], TraditionalForm]],ExpressionUUID->
  "1ce6732f-fa7a-478c-b319-b0441f269193"],
 "\ndefine a normalized radial location variable,\n\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    OverscriptBox["R", "_"], "=", 
    FractionBox[
     RowBox[{"R", "-", "c"}], 
     RowBox[{"b", "-", "c"}]]}], TraditionalForm]],ExpressionUUID->
  "357fc906-305b-452f-aedd-b99ba076f5a4"],
 "\nNote that\n\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    OverscriptBox["R", "_"], "=", 
    RowBox[{"-", "1"}]}], TraditionalForm]],ExpressionUUID->
  "59762907-9788-4de5-b2ae-ce70f7fb7bf6"],
 " at R=a\n\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    OverscriptBox["R", "_"], "=", 
    RowBox[{"+", "1"}]}], TraditionalForm]],ExpressionUUID->
  "6c0f589e-acff-49aa-8a97-177dfe0c93b1"],
 " at R=b\ndefine\n\t\[Eta] ",
 Cell[BoxData[
  FormBox[
   RowBox[{"=", 
    RowBox[{
     SubscriptBox["c", "0"], "+"}]}], TraditionalForm]],ExpressionUUID->
  "ad91df0f-4079-40cb-b3cf-149e30c4e4aa"],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["c", "2"], 
     SuperscriptBox[
      OverscriptBox["R", "_"], "2"]}], "+", 
    RowBox[{
     SubscriptBox["c", "4"], 
     SuperscriptBox[
      OverscriptBox["R", "_"], "4"]}]}], TraditionalForm]],ExpressionUUID->
  "a7dd76d1-af0b-484a-860d-b8672327f188"],
 "\n\t",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{"d", " ", "\[Eta]"}], 
    RowBox[{"d", 
     OverscriptBox["R", "_"]}]], TraditionalForm]],ExpressionUUID->
  "709b63e4-9a45-40fa-b8ec-0551ba1e6c5a"],
 " = ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"2", " ", 
     SubscriptBox["c", "2"], 
     OverscriptBox["R", "_"]}], "+", 
    RowBox[{"4", " ", 
     SubscriptBox["c", "4"], 
     SuperscriptBox[
      OverscriptBox["R", "_"], "3"]}]}], TraditionalForm]],ExpressionUUID->
  "9e4ace9a-199f-4277-a548-76d47422a801"],
 "\nDemand that\n\t\[Eta][0]=1\t\t\[DoubleLongRightArrow]\t\t",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", "0"], TraditionalForm]],ExpressionUUID->
  "51892ff5-3350-4eeb-94c7-4d380dade8c1"],
 "=1\n\t\[Eta][1]=0\t\t\[DoubleLongRightArrow]\t\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["c", "0"], "+", 
    SubscriptBox["c", "2"], "+", 
    SubscriptBox["c", "4"]}], TraditionalForm]],ExpressionUUID->
  "94866e53-ea43-4670-a467-01abc719c9b2"],
 "=0\n\t\[Eta]'[1]=0\t\t\[DoubleLongRightArrow]\t\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"2", " ", 
     SubscriptBox["c", "2"]}], "+", 
    RowBox[{"4", " ", 
     SubscriptBox["c", "4"]}]}], TraditionalForm]],ExpressionUUID->
  "3d61eaba-6587-4815-8a7b-589447c719fe"],
 "=0\n\t\nThus\n\t",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", "0"], TraditionalForm]],ExpressionUUID->
  "e5b61461-c932-444c-b913-4813545f448b"],
 "=1\n\t",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", "4"], TraditionalForm]],ExpressionUUID->
  "fbeb36d7-20ef-4ef0-959f-0ed933a3cc53"],
 "=1\n\t",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    SubscriptBox["c", "2"]}], TraditionalForm]],ExpressionUUID->
  "d6120b48-47af-4ede-9b3e-afd40d527002"],
 "=-2"
}], "Text",
 CellChangeTimes->{{3.4852547834070144`*^9, 3.485254885205014*^9}, {
  3.4852549347640142`*^9, 3.485255028547014*^9}, {3.4852550599700146`*^9, 
  3.4852554290440145`*^9}, {3.4852554884780145`*^9, 3.4852554980200143`*^9}, {
  3.485266733881296*^9, 3.485266789666994*^9}, {3.750780896794808*^9, 
  3.7507809241860743`*^9}},ExpressionUUID->"7569dd7b-26f7-4086-9a26-\
46dc9d728e4d"],

Cell["\<\
The following plot confirms that this function is zero and has zero slope at \
its endpoints:\
\>", "Text",
 CellChangeTimes->{{3.750781133721472*^9, 
  3.750781149033619*^9}},ExpressionUUID->"88f0fb83-a95d-46ed-b0b1-\
fb5c7bfb4dd5"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Eta]", "[", "Rbar_", "]"}], ":=", 
  RowBox[{"1", "-", 
   RowBox[{"2", 
    SuperscriptBox["Rbar", "2"]}], "+", 
   SuperscriptBox["Rbar", "4"]}]}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"\[Eta]", "[", "Rbar", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"Rbar", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.4852550313800144`*^9, 3.4852550451380143`*^9}, {
   3.485255504804014*^9, 3.4852555295360146`*^9}, {3.4852555773520145`*^9, 
   3.4852555936440144`*^9}, {3.7507810037779493`*^9, 3.750781016377926*^9}, {
   3.7507810680014305`*^9, 3.7507810781382136`*^9}, 3.7507813307787247`*^9, 
   3.7507870405838065`*^9},ExpressionUUID->"c87c440e-09fb-4ddf-ae65-\
c45ed7827bf7"],

Cell["\<\
Perform a change of variables to get a similar bump from radial locations a \
to b.
This defines the shape for the ring deformation, h[R]:\
\>", "Text",
 CellChangeTimes->{{3.7507811546098003`*^9, 3.7507811742095976`*^9}, {
  3.7507812739937773`*^9, 
  3.7507812868897223`*^9}},ExpressionUUID->"e693583b-d3e4-4f93-933a-\
f206ad230a69"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"rref", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a", "=", 
   RowBox[{"rref", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"1", "/", "4"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"b", "=", 
   RowBox[{"rref", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"1", "/", "4"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c", "=", 
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"(", 
     RowBox[{"b", "+", "a"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"h", "[", "R_", "]"}], ":=", 
  RowBox[{"Evaluate", "[", 
   RowBox[{"\[Eta]", "[", 
    FractionBox[
     RowBox[{"R", "-", "c"}], 
     RowBox[{"b", "-", "c"}]], "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"h", "[", "R", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"R", ",", "a", ",", "b"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"b", "+", 
         RowBox[{"a", "/", "2"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"h", "[", "R", "]"}]}], "Input",
 CellChangeTimes->{{3.4852555628820143`*^9, 3.4852555650170145`*^9}, {
  3.4852555981950145`*^9, 3.4852557233740144`*^9}, {3.4852557597460146`*^9, 
  3.4852558134800143`*^9}, {3.4852559991290145`*^9, 3.4852560007750144`*^9}, {
  3.4852562288730145`*^9, 3.4852563273290143`*^9}, {3.485256403023014*^9, 
  3.4852564950860147`*^9}, {3.7507810390127015`*^9, 3.7507810493543816`*^9}, {
  3.7507812035102262`*^9, 3.750781262090578*^9}, {3.7507813504264727`*^9, 
  3.7507814275229836`*^9}},ExpressionUUID->"4a4168ee-08a7-4297-911b-\
f13144013c98"],

Cell["\<\
It is understood that the h[R] function must evaluate to zero for R<a and for \
R>b.\
\>", "Text",
 CellChangeTimes->{{3.750781536602164*^9, 
  3.7507815616821995`*^9}},ExpressionUUID->"427dd458-6915-4754-9498-\
9189adc38be9"],

Cell["Reference shear strain within the zone a<R<b:", "Text",
 CellChangeTimes->{{3.507318671142124*^9, 3.507318673603965*^9}, {
  3.7507812971054745`*^9, 3.7507812998095956`*^9}, {3.7507815667855625`*^9, 
  3.750781593761937*^9}},ExpressionUUID->"53d71845-bc4b-4f94-bd3f-\
4d7b55bdbd02"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Xi]", "[", "R_", "]"}], ":=", 
  RowBox[{
   FractionBox["1", "2"], "R", " ", 
   RowBox[{
    RowBox[{"h", "'"}], "[", "R", "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"\[Xi]", "[", "R", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"R", ",", "a", ",", "b"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"b", "+", 
         RowBox[{"a", "/", "2"}]}]}], "}"}], ",", "All"}], "}"}]}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"\[Xi]", "[", "R", "]"}]}], "Input",
 CellChangeTimes->{{3.4852317006960144`*^9, 3.4852317451560144`*^9}, {
  3.4852565190030146`*^9, 
  3.4852565475390143`*^9}},ExpressionUUID->"7b51acee-cb88-4c51-9638-\
a06bf6c3a7ed"],

Cell["\<\
This is the shear strain in the material when the amplitude function g[t] is \
unity.\
\>", "Text",
 CellChangeTimes->{{3.75078160491439*^9, 
  3.7507816274821944`*^9}},ExpressionUUID->"64e1da30-6c5b-48bc-a6ba-\
a3cf1f9cba80"],

Cell["\<\

Step 2:  \
\>", "Text",
 CellChangeTimes->{{3.4852312175720143`*^9, 3.4852312355960145`*^9}, 
   3.4852313318030148`*^9, {3.4852331950700145`*^9, 3.4852332009060144`*^9}, 
   3.485233347304014*^9},ExpressionUUID->"c183c949-891c-4ab3-9d0d-\
a818c17d4c5e"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[ScriptCapitalF]", "=", 
   RowBox[{"(", GridBox[{
      {"1", "0", "0"},
      {
       RowBox[{"2", "\[Epsilon]"}], "1", "0"},
      {"0", "0", "1"}
     }], ")"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"J", "=", 
  RowBox[{"Det", "[", "\[ScriptCapitalF]", "]"}]}]}], "Input",
 CellChangeTimes->{{3.4852312648590145`*^9, 3.4852313167930145`*^9}, {
  3.4852313503520145`*^9, 3.485231353167014*^9}, {3.4852671940041046`*^9, 
  3.4852672277469635`*^9}},ExpressionUUID->"76f4bfc8-57e9-4dd6-9c67-\
c19fc3a499e8"],

Cell[TextData[{
 "Consider, as an example, simple neo-Hookian constitutive model. \nUnder \
conditions of simple shear, with the deformation gradient tensor given by the \
formula in the boxed cell above.\nBelow is the calculation of Cauchy stress ",
 Cell[BoxData[
  FormBox[
   UnderscriptBox["\[Sigma]", "\[TildeTilde]"], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "84c99d2e-a417-4fc6-b7ae-2bc0f2228a89"],
 " from this deformation.\nKeep in mind that our MMS calculation of the body \
force requires components of the PK1 stress, not the Cauchy stress, so an \
appropriate conversion is performed using standard transformations in \
Continuum Mechanics:"
}], "Text",
 CellChangeTimes->{
  3.4852313352610145`*^9, {3.750781640681955*^9, 
   3.750781902986745*^9}},ExpressionUUID->"162060f2-fc2a-4289-ab90-\
33487d5a10ec"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Tau]", "=", 
   RowBox[{"2", "G", " ", "\[Epsilon]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[DoubleStruckCapitalI]", "=", 
   RowBox[{"IdentityMatrix", "[", "3", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]", "=", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"\[Lambda]", " ", 
       RowBox[{"Log", "[", "J", "]"}]}], "J"], "\[DoubleStruckCapitalI]"}], 
    "+", 
    RowBox[{
     FractionBox["\[Mu]", "J"], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[ScriptCapitalF]", ".", 
        RowBox[{"Transpose", "[", "\[ScriptCapitalF]", "]"}]}], "-", 
       "\[DoubleStruckCapitalI]"}], ")"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<Cauchy stress is \>\"", ",", 
    RowBox[{"\[Sigma]", "//", "MatrixForm"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "Print", "[", 
   "\"\<But we need the PK1 stress, which is, for this model,...\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PK2", "=", 
   RowBox[{
    RowBox[{"Inverse", "[", "\[ScriptCapitalF]", "]"}], ".", 
    RowBox[{"(", 
     RowBox[{"J", " ", "\[Sigma]"}], ")"}], ".", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Inverse", "[", "\[ScriptCapitalF]", "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[ScriptCapitalT]", "=", 
   RowBox[{"PK1", "=", 
    RowBox[{
     RowBox[{"\[ScriptCapitalF]", ".", "PK2"}], "//", "Simplify"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"\[ScriptCapitalT]", "//", "MatrixForm"}]}], "Input",
 CellChangeTimes->{{3.4852312387820144`*^9, 3.4852312468850145`*^9}, {
   3.485231362212014*^9, 3.4852315489140143`*^9}, 3.4852316784920144`*^9, {
   3.485232176863014*^9, 3.4852321896730146`*^9}, {3.4852672492282014`*^9, 
   3.4852672835326614`*^9}, {3.4852673705808144`*^9, 
   3.4852674656941814`*^9}, {3.7507819215158286`*^9, 
   3.7507819886745358`*^9}},ExpressionUUID->"0fd082ed-8a75-455e-945b-\
75c714a0423b"],

Cell["\<\
Incidentally, we note that this simple shear motion induces a nonzero \
mechanical pressure:\
\>", "Text",
 CellChangeTimes->{{3.7507820068337803`*^9, 
  3.7507820320907583`*^9}},ExpressionUUID->"0a1a8231-7cf6-4ae0-a224-\
aea0d442caf1"],

Cell[BoxData[
 RowBox[{"pressure", "=", 
  RowBox[{
   FractionBox["1", "3"], 
   RowBox[{"Tr", "[", "\[Sigma]", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4852676425048923`*^9, 
  3.485267659898923*^9}},ExpressionUUID->"8fd56f0f-d9dd-40e3-86b0-\
aa49f285b5be"],

Cell[TextData[{
 "\n\nStep 3:\nApply formula for evaluating the body forces components:\n\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["b", "r"], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "R"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"g", "'"}], "[", "t", "]"}], " ", 
         RowBox[{"h", "[", "R", "]"}]}], ")"}], "2"]}], "-", 
     RowBox[{
      FractionBox["1", 
       SubscriptBox["\[Rho]", "0"]], 
      RowBox[{"{", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"\[Xi]", "'"}], "[", "R", "]"}], "  ", 
            FractionBox[
             RowBox[{"d", " ", 
              SubscriptBox["\[ScriptCapitalT]", "11"]}], 
             RowBox[{"d", " ", "\[Epsilon]"}]]}], "-", 
           RowBox[{
            RowBox[{
             RowBox[{"h", "'"}], "[", "R", "]"}], 
            SubscriptBox["\[ScriptCapitalT]", "21"]}]}], ")"}], 
         RowBox[{"g", "[", "t", "]"}]}], "+", 
        RowBox[{
         FractionBox["1", "R"], 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[ScriptCapitalT]", "11"], "-", 
           SubscriptBox["\[ScriptCapitalT]", "22"]}], ")"}]}]}], "}"}]}]}]}], 
   TraditionalForm]],ExpressionUUID->"7a9aa322-8b24-45cd-a170-a59c911927f9"],
 "\n\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["b", "\[CurlyTheta]"], "=", 
    RowBox[{
     RowBox[{"R", " ", 
      RowBox[{
       RowBox[{"g", "''"}], "[", "t", "]"}], " ", 
      RowBox[{"h", "[", "R", "]"}]}], "-", 
     RowBox[{
      FractionBox["1", 
       SubscriptBox["\[Rho]", "0"]], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"\[Xi]", "'"}], "[", "R", "]"}], "  ", 
            FractionBox[
             RowBox[{"d", " ", 
              SubscriptBox["\[ScriptCapitalT]", "21"]}], 
             RowBox[{"d", " ", "\[Epsilon]"}]]}], "+", 
           RowBox[{
            RowBox[{
             RowBox[{"h", "'"}], "[", "R", "]"}], 
            SubscriptBox["\[ScriptCapitalT]", "11"]}]}], ")"}], 
         RowBox[{"g", "[", "t", "]"}]}], "+", 
        RowBox[{
         FractionBox["1", "R"], 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[ScriptCapitalT]", "12"], "+", 
           SubscriptBox["\[ScriptCapitalT]", "21"]}], ")"}]}]}], "}"}]}]}]}], 
   TraditionalForm]],ExpressionUUID->"a0063232-dfbb-4969-900e-879744f7b2a0"]
}], "Text",
 CellChangeTimes->{{3.485231585021014*^9, 3.4852315931990147`*^9}, {
   3.485233361370014*^9, 3.4852333675650144`*^9}, 3.4852677333126516`*^9, {
   3.750782053179025*^9, 
   3.750782065107478*^9}},ExpressionUUID->"bb0b9893-b222-4536-b4b4-\
2de22663a41f"],

Cell[BoxData[
 RowBox[{"br", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "R"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"g", "'"}], "[", "t", "]"}], 
         RowBox[{"h", "[", "R", "]"}]}], ")"}], "2"]}], "-", 
     RowBox[{
      FractionBox["1", "\[Rho]0"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"\[Xi]", "'"}], "[", "R", "]"}], " ", 
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{"\[ScriptCapitalT]", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", "\[Epsilon]"}], 
             "]"}]}], "-", 
           RowBox[{
            RowBox[{
             RowBox[{"h", "'"}], "[", "R", "]"}], " ", 
            RowBox[{"\[ScriptCapitalT]", "[", 
             RowBox[{"[", 
              RowBox[{"2", ",", "1"}], "]"}], "]"}]}]}], ")"}], 
         RowBox[{"g", "[", "t", "]"}]}], "+", 
        RowBox[{
         FractionBox["1", "R"], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[ScriptCapitalT]", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", 
           RowBox[{"\[ScriptCapitalT]", "[", 
            RowBox[{"[", 
             RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ")"}]}]}], ")"}]}]}], "/.", 
    RowBox[{"\[Epsilon]", "\[Rule]", 
     RowBox[{
      RowBox[{"g", "[", "t", "]"}], 
      RowBox[{"\[Xi]", "[", "R", "]"}]}]}]}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.4852315964710145`*^9, 3.4852316350690145`*^9}, {
  3.4852316716240144`*^9, 3.4852316871760144`*^9}, {3.485231753799014*^9, 
  3.4852319097810144`*^9}, {3.4852319680720143`*^9, 3.485231969839014*^9}, {
  3.4852320110120144`*^9, 3.4852320365390143`*^9}, {3.4852678129351916`*^9, 
  3.4852678176776*^9}},ExpressionUUID->"9a740772-cfb0-4523-bda5-f8967aab7b75"],

Cell[BoxData[
 RowBox[{"b\[CurlyTheta]", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"R", " ", 
      RowBox[{
       RowBox[{"g", "''"}], "[", "t", "]"}], 
      RowBox[{"h", "[", "R", "]"}]}], "-", 
     RowBox[{
      FractionBox["1", "\[Rho]0"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"\[Xi]", "'"}], "[", "R", "]"}], " ", 
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{"\[ScriptCapitalT]", "[", 
               RowBox[{"[", 
                RowBox[{"2", ",", "1"}], "]"}], "]"}], ",", "\[Epsilon]"}], 
             "]"}]}], "+", 
           RowBox[{
            RowBox[{
             RowBox[{"h", "'"}], "[", "R", "]"}], 
            RowBox[{"\[ScriptCapitalT]", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "1"}], "]"}], "]"}]}]}], ")"}], 
         RowBox[{"g", "[", "t", "]"}]}], "+", 
        RowBox[{
         FractionBox["1", "R"], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[ScriptCapitalT]", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "2"}], "]"}], "]"}], "+", 
           RowBox[{"\[ScriptCapitalT]", "[", 
            RowBox[{"[", 
             RowBox[{"2", ",", "1"}], "]"}], "]"}]}], ")"}]}]}], ")"}]}]}], "/.", 
    RowBox[{"\[Epsilon]", "\[Rule]", 
     RowBox[{
      RowBox[{"g", "[", "t", "]"}], 
      RowBox[{"\[Xi]", "[", "R", "]"}]}]}]}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.4852319194960146`*^9, 3.4852319997650146`*^9}, {
  3.4852320715590143`*^9, 3.4852321405000143`*^9}, {3.4852678697036915`*^9, 
  3.4852678707176933`*^9}},ExpressionUUID->"5ae51c84-5d15-496e-8960-\
b9c4a3e8fd97"],

Cell["\<\


Step 4:
body force vector relative to spatial cylindrical basis\
\>", "Text",
 CellChangeTimes->{{3.4852333842160144`*^9, 
  3.485233436056014*^9}},ExpressionUUID->"bfb57d10-f866-4bab-a63b-\
9d37c2612302"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"bcylindrical", "=", 
   RowBox[{"{", 
    RowBox[{"br", ",", "b\[CurlyTheta]", ",", "0"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"bcylindrical", "//", "MatrixForm"}]}], "Input",
 CellChangeTimes->{{3.485232310172014*^9, 3.4852323649510145`*^9}, {
  3.4852325898890142`*^9, 3.4852325908210144`*^9}, {3.485232765712014*^9, 
  3.4852327710570145`*^9}, {3.4852705725800385`*^9, 
  3.485270584092859*^9}},ExpressionUUID->"98048b75-7043-4ad6-8d3d-\
3458d9a761cb"],

Cell["\<\
body force vector in Cartesian basis, recognizing that the current angular \
coordinate is the initial coordinate \[CapitalTheta] plus the material \
rotation angle \[Alpha]:\
\>", "Text",
 CellChangeTimes->{{3.4852334191230145`*^9, 3.4852334321700144`*^9}, 
   3.4852679968127146`*^9, {3.750782099738398*^9, 
   3.750782132778887*^9}},ExpressionUUID->"1ad93a5f-87b6-4509-b608-\
56f67b0edf1e"],

Cell[BoxData[
 RowBox[{"\[CurlyTheta]", "=", 
  RowBox[{"\[CapitalTheta]", "+", "\[Alpha]"}]}]], "Input",
 CellChangeTimes->{{3.4852324662460146`*^9, 
  3.4852324791050143`*^9}},ExpressionUUID->"b03acf52-96e2-4709-9751-\
7879879f316c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dircos", "=", 
   RowBox[{"(", GridBox[{
      {
       RowBox[{"Cos", "[", "\[CurlyTheta]", "]"}], 
       RowBox[{"Sin", "[", "\[CurlyTheta]", "]"}], "0"},
      {
       RowBox[{"-", 
        RowBox[{"Sin", "[", "\[CurlyTheta]", "]"}]}], 
       RowBox[{"Cos", "[", "\[CurlyTheta]", "]"}], "0"},
      {"0", "0", "1"}
     }], ")"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4852323776450143`*^9, 3.485232449969014*^9}, 
   3.4852325631360145`*^9},ExpressionUUID->"fb4ec805-c4e3-4452-8767-\
d532a7f97175"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"bCartesian", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Transpose", "[", "dircos", "]"}], ".", "bcylindrical"}], "//", 
    "Simplify"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"bCartesian", "//", "MatrixForm"}]}], "Input",
 CellChangeTimes->{{3.4852323679870143`*^9, 3.485232371648014*^9}, {
  3.4852325717220144`*^9, 3.485232616141014*^9}, {3.4852326626060143`*^9, 
  3.4852326716620145`*^9}, {3.4852327072840147`*^9, 
  3.4852327528190145`*^9}},ExpressionUUID->"69e304e6-afc1-4564-860e-\
54f784979ff7"],

Cell[BoxData[
 RowBox[{"bcylindrical", "/.", 
  RowBox[{"{", 
   RowBox[{"R", "\[Rule]", 
    RowBox[{"3", "/", "4"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.4852680605232267`*^9, 3.4852680748908515`*^9}, {
  3.485268144513774*^9, 
  3.4852681675394144`*^9}},ExpressionUUID->"4df0239b-ad2a-4192-a4d4-\
05ba3207e422"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Verification that the spatial eqs of motion are satisfied by this MMS\
\>", "Section",
 CellChangeTimes->{{3.48526839272581*^9, 
  3.4852684071714354`*^9}},ExpressionUUID->"76cfb5a2-86af-4880-b056-\
6e129d9bd2b5"],

Cell["\<\
Define a notationally appealing macro that lets us access vector components \
as subscripts instead of the ugly two-bracket [[ ... ]] syntax that is the \
default in Mathematica:\
\>", "Text",
 CellChangeTimes->{{3.750782158170785*^9, 
  3.750782196266657*^9}},ExpressionUUID->"699833d8-ceec-421f-9304-\
99806aea8d2d"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["u_", "j__"], ":=", 
  RowBox[{"u", "[", 
   RowBox[{"[", "j", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4852687649580636`*^9, 
  3.485268844783404*^9}},ExpressionUUID->"a96eb020-8a7e-4f54-b122-\
bbe62b84e6c8"],

Cell["\<\
Let\[CloseCurlyQuote]s remind ourselves of the Cauchy stress tensor in the \
case of simple shear without superimposed rotation:\
\>", "Text",
 CellChangeTimes->{{3.7507822018749065`*^9, 
  3.7507822557307777`*^9}},ExpressionUUID->"b36d3d0f-ca78-463b-b633-\
99f9cc7dbd8d"],

Cell[BoxData[
 RowBox[{"\[Sigma]", "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.4852685024720025`*^9, 3.4852685036108046`*^9}, {
  3.4852691634139633`*^9, 3.4852691668147697`*^9}, {3.7507822592596483`*^9, 
  3.750782261163063*^9}},ExpressionUUID->"180ae742-31b0-455b-8ff7-\
4fd578644aab"],

Cell["\<\
Based on our analysis of this MMS, these Cartesian components for the simple \
shear problem without superimposed rotation are the same as the spatial \
cylindrical components in the actual MMS problem.

Define a substitution pattern that replaces the generic strain with its \
actual value as a function of position and time. Also include a substitution \
that specifies the current radial coordinate to be equal to the initial one:\
\>", "Text",
 CellChangeTimes->{{3.7507822728583713`*^9, 3.7507823679862995`*^9}, {
  3.7507824858667107`*^9, 
  3.750782551954897*^9}},ExpressionUUID->"4bffe12b-59b4-4326-9b72-\
22d7e8d8806d"],

Cell[BoxData[
 RowBox[{"sub", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"\[Epsilon]", "\[Rule]", 
     RowBox[{
      RowBox[{"g", "[", "t", "]"}], 
      RowBox[{"\[Xi]", "[", "R", "]"}]}]}], ",", 
    RowBox[{"R", "\[Rule]", "r"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.485269338493071*^9, 
  3.4852693637651157`*^9}},ExpressionUUID->"b2a94471-9843-444b-b772-\
5e84f78d0185"],

Cell["\<\
Obtain the cylindrical components of Cauchy stress as functions of position \
and time:\
\>", "Text",
 CellChangeTimes->{{3.750782380090437*^9, 
  3.750782424602287*^9}},ExpressionUUID->"ea293819-5c48-4e4e-8cf2-\
9a1ebac7564a"],

Cell[BoxData[
 RowBox[{"\[Sigma]rr", "=", 
  SubscriptBox["\[Sigma]", 
   RowBox[{"1", ",", "1"}]]}]], "Input",
 CellChangeTimes->{{3.485269210479246*^9, 
  3.4852692364064913`*^9}},ExpressionUUID->"98506859-0a72-4e5e-bf18-\
1d777fcd4de8"],

Cell[BoxData[
 RowBox[{"\[Sigma]r\[CurlyTheta]", "=", 
  RowBox[{
   SubscriptBox["\[Sigma]", 
    RowBox[{"1", ",", "2"}]], "//.", "sub"}]}]], "Input",
 CellChangeTimes->{{3.485269256452527*^9, 3.485269288214183*^9}, {
   3.485269354264699*^9, 3.4852693563395023`*^9}, 
   3.4852693876799574`*^9},ExpressionUUID->"abcc3cb1-a08d-4214-aec1-\
6a3c6914dd6d"],

Cell[BoxData[
 RowBox[{"\[Sigma]\[CurlyTheta]r", "=", 
  RowBox[{
   SubscriptBox["\[Sigma]", 
    RowBox[{"2", ",", "1"}]], "//.", "sub"}]}]], "Input",
 CellChangeTimes->{{3.4852694491752653`*^9, 
  3.4852694730433073`*^9}},ExpressionUUID->"84822f05-cf3f-423d-92b5-\
a90fcabae486"],

Cell[BoxData[
 RowBox[{"\[Sigma]\[CurlyTheta]\[CurlyTheta]", "=", 
  RowBox[{
   SubscriptBox["\[Sigma]", 
    RowBox[{"2", ",", "2"}]], "//.", "sub"}]}]], "Input",
 CellChangeTimes->{{3.4852694874577327`*^9, 
  3.4852694959129477`*^9}},ExpressionUUID->"de3557b9-df42-440a-9e0e-\
d45bf9c62a9b"],

Cell["\<\
Now compute the radial and tangential components of the stress divergence:\
\>", "Text",
 CellChangeTimes->{{3.4852685962281675`*^9, 3.485268653090267*^9}, {
  3.750782583618788*^9, 
  3.750782601883016*^9}},ExpressionUUID->"fafda931-bcc5-4fb7-bae1-\
438ee0f34bcb"],

Cell[BoxData[{
 RowBox[{"divSigr", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox["1", "r"], 
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"r", " ", "\[Sigma]rr"}], ",", "r"}], "]"}]}], "-", 
    FractionBox["\[Sigma]\[CurlyTheta]\[CurlyTheta]", "r"]}], "//", 
   "Simplify"}]}], "\[IndentingNewLine]", 
 RowBox[{"divSig\[CurlyTheta]", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox["1", 
      SuperscriptBox["r", "2"]], 
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{
        SuperscriptBox["r", "2"], " ", "\[Sigma]\[CurlyTheta]r"}], ",", "r"}],
       "]"}]}], "+", 
    RowBox[{
     FractionBox["1", "r"], 
     RowBox[{"(", 
      RowBox[{"\[Sigma]\[CurlyTheta]r", "-", "\[Sigma]r\[CurlyTheta]"}], 
      ")"}]}]}], "//", "Simplify"}]}]}], "Input",
 CellChangeTimes->{{3.485268459369127*^9, 3.4852684973707933`*^9}, {
  3.4852685784909363`*^9, 3.4852685883501534`*^9}, {3.485268753164443*^9, 
  3.4852687553016467`*^9}, {3.485268880866267*^9, 3.4852689859636517`*^9}, {
  3.485269113899476*^9, 3.485269143960729*^9}, {3.4852695096721716`*^9, 
  3.48526955431945*^9}, {3.485269674205661*^9, 3.4852697341565657`*^9}, {
  3.4852698096918983`*^9, 3.4852698105499*^9}, {3.4852700726459603`*^9, 
  3.4852701530485015`*^9}, {3.4852702356818466`*^9, 
  3.4852702769751196`*^9}},ExpressionUUID->"51c5ff2e-43a3-4fe6-aa8e-\
3c04c44ba9de"],

Cell[TextData[{
 "Recall that that  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderscriptBox["x", "~"], "=", 
    RowBox[{
     RowBox[{"r", " ", 
      SubscriptBox[
       StyleBox[
        UnderscriptBox[
         StyleBox["e",
          FontSlant->"Plain"], "~"],
        FontWeight->"Bold",
        FontSlant->"Italic"], "r"]}], "=", 
     RowBox[{"R", " ", 
      SubscriptBox[
       StyleBox[
        UnderscriptBox[
         StyleBox["e",
          FontSlant->"Plain"], "~"],
        FontWeight->"Bold",
        FontSlant->"Italic"], "r"]}]}]}], TraditionalForm]],ExpressionUUID->
  "2a1eadba-294a-490c-90e1-9c54120afc90"],
 "\n\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderscriptBox["v", "~"], "=", 
    RowBox[{"R", " ", "\[Omega]", " ", 
     SubscriptBox[
      StyleBox[
       UnderscriptBox[
        StyleBox["e",
         FontSlant->"Plain"], "~"],
       FontWeight->"Bold",
       FontSlant->"Italic"], "\[CurlyTheta]"]}]}], TraditionalForm]],
  ExpressionUUID->"7986f9f7-ced1-4dd6-8586-74ba982d8a85"],
 ",  \n\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderscriptBox["a", "~"], "=", 
    RowBox[{
     RowBox[{"R", " ", 
      OverscriptBox["\[Omega]", "."], " ", 
      SubscriptBox[
       StyleBox[
        UnderscriptBox[
         StyleBox["e",
          FontSlant->"Plain"], "~"],
        FontWeight->"Bold",
        FontSlant->"Italic"], "\[CurlyTheta]"]}], "-", 
     RowBox[{"R", " ", 
      SuperscriptBox["\[Omega]", "2"], " ", 
      SubscriptBox[
       StyleBox[
        UnderscriptBox[
         StyleBox["e",
          FontSlant->"Plain"], "~"],
        FontWeight->"Bold",
        FontSlant->"Italic"], "r"]}]}]}], TraditionalForm]],ExpressionUUID->
  "9a9b084f-ca6a-4396-86ef-8ad6446a1dd3"],
 "\nwhere \t\n\t\[Omega]=g'[t] h[R]\nand\n\t",
 Cell[BoxData[
  FormBox[
   OverscriptBox["\[Omega]", "."], TraditionalForm]],ExpressionUUID->
  "a5b6603d-7fc9-47c1-a4c7-2542f8edb5a8"],
 "=g''[t]  h[R]"
}], "Text",
 CellChangeTimes->{{3.485269794591072*^9, 3.485269798693879*^9}, {
  3.7507826123146863`*^9, 
  3.7507826297711353`*^9}},ExpressionUUID->"3b2cbd70-56e5-4270-8a96-\
433c76d89399"],

Cell[BoxData[{
 RowBox[{"\[Omega]", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"g", "'"}], "[", "t", "]"}], 
    RowBox[{"h", "[", "R", "]"}]}], "//.", "sub"}]}], "\[IndentingNewLine]", 
 RowBox[{"\[Omega]dot", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"g", "''"}], "[", "t", "]"}], 
    RowBox[{"h", "[", "R", "]"}]}], "//.", "sub"}]}]}], "Input",
 CellChangeTimes->{{3.4852698299875345`*^9, 
  3.4852698836048284`*^9}},ExpressionUUID->"4225244e-9cdc-4004-aaca-\
5f6b44d8c3ae"],

Cell["\<\
Noting that the current mass density equals initial mass density divided by \
the Jacobian, the components of density times acceleration as well as density \
times body force are given by\
\>", "Text",
 CellChangeTimes->{{3.750782653330614*^9, 
  3.750782752363083*^9}},ExpressionUUID->"7d17ebb7-99bc-4bca-8616-\
c2c50a9d7911"],

Cell[BoxData[{
 RowBox[{"\[Rho]ar", "=", 
  RowBox[{
   FractionBox["\[Rho]0", "J"], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "r"}], " ", 
     SuperscriptBox["\[Omega]", "2"]}], ")"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"\[Rho]br", "=", 
  RowBox[{
   RowBox[{
    FractionBox["\[Rho]0", "J"], 
    RowBox[{"bcylindrical", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "//.", "sub"}]}]}], "Input",
 CellChangeTimes->{{3.4852698225931215`*^9, 3.4852698237475233`*^9}, {
   3.485269899719657*^9, 3.4852699472685404`*^9}, 
   3.485270038622301*^9},ExpressionUUID->"5a8ab21d-8036-419c-97be-\
81ac42444e4c"],

Cell[BoxData[{
 RowBox[{"\[Rho]a\[CurlyTheta]", "=", 
  RowBox[{
   FractionBox["\[Rho]0", "J"], 
   RowBox[{"(", 
    RowBox[{"r", " ", "\[Omega]dot"}], ")"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"\[Rho]b\[CurlyTheta]", "=", 
  RowBox[{
   RowBox[{
    FractionBox["\[Rho]0", "J"], 
    RowBox[{"bcylindrical", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], "//.", "sub"}]}]}], "Input",
 CellChangeTimes->{{3.485270303635566*^9, 
  3.4852703510440493`*^9}},ExpressionUUID->"344c9108-2069-408a-81a8-\
9f8127a0087b"],

Cell["\<\
The following now confirms that the derived body force does indeed satisfy \
the equations of motion:\
\>", "Text",
 CellChangeTimes->{{3.7507827597307477`*^9, 
  3.7507827760346527`*^9}},ExpressionUUID->"f8862ef6-5ffc-43a3-9fe2-\
dffe1431c939"],

Cell[BoxData[{
 RowBox[{"Simplify", "[", 
  RowBox[{"divSigr", "+", "\[Rho]br", "-", "\[Rho]ar"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
  "divSig\[CurlyTheta]", "+", "\[Rho]b\[CurlyTheta]", "-", 
   "\[Rho]a\[CurlyTheta]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.4852699720413837`*^9, 3.485269994037422*^9}, {
  3.4852703680324793`*^9, 
  3.485270383226906*^9}},ExpressionUUID->"10b02881-d52f-4ab1-85d3-\
f8e38cbaef6c"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualization", "Section",
 CellChangeTimes->{{3.5073113169467497`*^9, 
  3.50731131875629*^9}},ExpressionUUID->"3a0905cd-0362-49eb-90e0-\
2b781155b023"],

Cell[BoxData[
 RowBox[{"SetDirectory", "[", 
  RowBox[{"NotebookDirectory", "[", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.507310445569841*^9, 
  3.507310455825378*^9}},ExpressionUUID->"7e3dca07-f4d5-488e-b939-\
20826c4758c7"],

Cell["\<\
Multiplier on the time increment between frames in movies (set =1 for high \
fidelity,  set =20 for just a few frames for testing).\
\>", "Text",
 CellChangeTimes->{{3.50732111398177*^9, 
  3.507321150644994*^9}},ExpressionUUID->"466e43e4-5f89-4835-a8b3-\
25228bf69ef8"],

Cell[BoxData[
 RowBox[{"fac", "=", "1"}]], "Input",
 CellChangeTimes->{{3.507315017296913*^9, 3.5073150205811377`*^9}, {
  3.507320948214163*^9, 
  3.507320948713274*^9}},ExpressionUUID->"79785c14-30a1-4c6d-9e0c-\
2b89f4582ff5"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Rbar", "=."}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Eta]", "[", "Rbar_", "]"}], ":=", 
  RowBox[{"1", "-", 
   RowBox[{"2", 
    SuperscriptBox["Rbar", "2"]}], "+", 
   SuperscriptBox["Rbar", "4"]}]}]}], "Input",
 CellChangeTimes->{{3.750782813203806*^9, 
  3.7507828344030185`*^9}},ExpressionUUID->"002593fa-38d8-4f0f-82d3-\
681229cc29ee"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Eta]", "'"}], "[", "Rbar", "]"}]], "Input",
 CellChangeTimes->{{3.507317555984774*^9, 3.507317559462367*^9}, 
   3.7507828262836328`*^9},ExpressionUUID->"19d63f19-f207-4565-977f-\
b82d5b0dd2ee"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"rref", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a", "=", 
   RowBox[{"rref", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"1", "/", "4"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"b", "=", 
   RowBox[{"rref", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"1", "/", "4"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c", "=", 
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"(", 
     RowBox[{"b", "+", "a"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"h", "[", "R_", "]"}], ":=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"a", "<", "R", "<", "b"}], ",", 
     RowBox[{"Evaluate", "[", 
      RowBox[{"\[Eta]", "[", 
       FractionBox[
        RowBox[{"R", "-", "c"}], 
        RowBox[{"b", "-", "c"}]], "]"}], "]"}], ",", "0"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"h", "[", "R", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"R", ",", "0", ",", 
     RowBox[{"1.2", "b"}]}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"h", "[", "R", "]"}]}], "Input",
 CellChangeTimes->{{3.5073099849849787`*^9, 3.5073100199759607`*^9}, {
  3.5073143765922003`*^9, 3.507314397417398*^9}, {3.750782854601569*^9, 
  3.7507828603157597`*^9}, {3.750782902028448*^9, 
  3.75078296165242*^9}},ExpressionUUID->"46bbccbf-92ec-405c-843e-\
381dd38d72d6"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"hprime", "[", "R_", "]"}], ":=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "a"}], "<", "R", "<", "b"}], ",", 
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{"\[Eta]", "'"}], "[", 
       FractionBox[
        RowBox[{"R", "-", "c"}], 
        RowBox[{"b", "-", "c"}]], "]"}], "]"}], ",", "0"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"hprime", "[", "R", "]"}]}], "Input",
 CellChangeTimes->{{3.507317488297419*^9, 3.5073175850807877`*^9}, {
   3.50731762791649*^9, 3.5073177602403316`*^9}, 
   3.7507829958045096`*^9},ExpressionUUID->"cd4f3703-be87-48e6-936f-\
b62765bf304c"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"tref", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g", "[", "t_", "]"}], ":=", 
  RowBox[{"Sin", "[", 
   RowBox[{"\[Pi]", " ", 
    FractionBox["t", "tref"]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"g", "[", "t", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", "tref"}]}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{
  3.507311024389545*^9},ExpressionUUID->"08f78e6f-101d-4b0a-aa8c-\
5936ff1882f7"],

Cell[TextData[{
 "Define a function to evaluate the continuum mapping,\n\t",
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderscriptBox["x", "~"], "=", 
    RowBox[{
     UnderscriptBox[
      UnderscriptBox["Q", "~"], "~"], ".", 
     UnderscriptBox["X", "~"]}]}], TraditionalForm]],ExpressionUUID->
  "fa39a342-8014-41a1-adca-d064626bf0af"]
}], "Text",
 CellChangeTimes->{{3.750783102915316*^9, 3.7507831670276475`*^9}, {
  3.7507835960676975`*^9, 
  3.7507835991317344`*^9}},ExpressionUUID->"ba2d19b0-979b-4cf4-8429-\
cade13138633"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ppts", "=", "30"}], ";"}]], "Input",
 CellChangeTimes->{{3.75078360069422*^9, 
  3.750783605371727*^9}},ExpressionUUID->"63c30cad-1cc8-472b-a900-\
f3a3476d6e5b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"q", "[", 
   RowBox[{"X1_", ",", "X2_", ",", "t_"}], "]"}], ":=", 
  RowBox[{"Evaluate", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", GridBox[{
         {
          RowBox[{"Cos", "[", "\[Alpha]", "]"}], 
          RowBox[{"-", 
           RowBox[{"Sin", "[", "\[Alpha]", "]"}]}]},
         {
          RowBox[{"Sin", "[", "\[Alpha]", "]"}], 
          RowBox[{"Cos", "[", "\[Alpha]", "]"}]}
        }], ")"}], "/.", 
      RowBox[{"{", 
       RowBox[{"\[Alpha]", "\[Rule]", 
        RowBox[{
         RowBox[{"g", "[", "t", "]"}], 
         RowBox[{"h", "[", "R", "]"}]}]}], "}"}]}], ")"}], "/.", 
    RowBox[{"{", 
     RowBox[{"R", "\[Rule]", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"X1", ",", "X2"}], "}"}], ".", 
        RowBox[{"{", 
         RowBox[{"X1", ",", "X2"}], "}"}]}], "]"}]}], "}"}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.507308605705863*^9, 3.507308789065959*^9}, {
   3.5073089261882687`*^9, 3.507308954417719*^9}, 
   3.507310153340827*^9},ExpressionUUID->"861a6770-4f34-46e5-837b-\
74d436522471"],

Cell[BoxData[
 RowBox[{
  RowBox[{"map", "[", 
   RowBox[{"X1_", ",", "X2_", ",", "t_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"q", "[", 
    RowBox[{"X1", ",", "X2", ",", "t"}], "]"}], ".", 
   RowBox[{"{", 
    RowBox[{"X1", ",", "X2"}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.507310157490906*^9, 
  3.507310183789446*^9}},ExpressionUUID->"85fdecab-2ada-453d-b9fe-\
cf600a60da72"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Xval", "=", 
   RowBox[{"1.2", "b"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dt", "=", 
   RowBox[{"fac", "*", ".02", " ", "tref"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"frames", "=", 
   RowBox[{"Table", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"map", "[", 
        RowBox[{"X1", ",", "X2", ",", "tval"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"X1", ",", 
         RowBox[{"-", "Xval"}], ",", "Xval"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"X2", ",", 
         RowBox[{"-", "Xval"}], ",", "Xval"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"MeshStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"Thick", ",", "Blue"}], "}"}], "}"}]}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "ppts"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Axes", "\[Rule]", "False"}], ",", 
       RowBox[{"Frame", "\[Rule]", "False"}]}], "]"}], "\[IndentingNewLine]", 
     ",", 
     RowBox[{"{", 
      RowBox[{"tval", ",", "0", ",", 
       RowBox[{
        RowBox[{"2", "tref"}], "-", "dt"}], ",", "dt"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{"\"\<GeneralizedVortexRing.gif\>\"", ",", "frames"}], 
  "]"}]}], "Input",
 CellChangeTimes->{
  3.5137314779570923`*^9, {3.513731634098782*^9, 3.5137316444436083`*^9}, 
   3.7507835515566483`*^9, 
   3.750783612860357*^9},ExpressionUUID->"93c0cdf0-6649-471d-8699-\
ce62b18d0993"],

Cell["\<\



The following exports single frames of the animation.
To make an animated gif from the exported frames, execute the following on a \
Linux Workstation:

convert -verbose -delay 30 -loop 0 -density 100 gvs*.gif \
GeneralizedVortexSquareSmall.gif

This notebook currently does not export the images of the individual frames. \
If you want them, uncomment the \[OpenCurlyDoubleQuote]do loop\
\[CloseCurlyDoubleQuote] below.\
\>", "Text",
 CellChangeTimes->{{3.5137192941575108`*^9, 3.513719356031639*^9}, {
   3.513719434302765*^9, 3.513719463971859*^9}, {3.513719853192477*^9, 
   3.513719859608273*^9}, 3.513719954560073*^9, {3.5137200711157722`*^9, 
   3.513720083870878*^9}, {3.750777438010027*^9, 
   3.750777487947194*^9}},ExpressionUUID->"4e3ea826-e408-4464-b64c-\
bc76d892863b"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"nfrms", "=", "40"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"inc", "=", 
   RowBox[{"Max", "[", 
    RowBox[{"2", ",", 
     RowBox[{"Round", "[", 
      FractionBox[
       RowBox[{"Length", "[", "frames", "]"}], "nfrms"], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Do", "[", 
    RowBox[{
     RowBox[{"Export", "[", 
      RowBox[{
       RowBox[{"\"\<gvs\>\"", "<>", 
        RowBox[{"IntegerString", "[", 
         RowBox[{"i", ",", "10", ",", "3"}], "]"}], "<>", "\"\<.gif\>\""}], 
       ",", 
       RowBox[{"frames", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "frames", "]"}], ",", "inc"}], "}"}]}], "]"}], 
   "*)"}]}]}], "Input",
 CellChangeTimes->{{3.513717331707492*^9, 3.513717364299511*^9}, {
   3.513717396693275*^9, 3.513717485036697*^9}, {3.513717700717195*^9, 
   3.5137177814581547`*^9}, {3.513717818626543*^9, 3.5137178340259247`*^9}, {
   3.513719094012022*^9, 3.5137190976502132`*^9}, {3.513719233472376*^9, 
   3.513719237932922*^9}, {3.513719868476447*^9, 3.5137198685458508`*^9}, 
   3.513719944465331*^9, {3.513721354643571*^9, 3.513721355114422*^9}, {
   3.513731706986067*^9, 3.5137317302133913`*^9}, {3.7507774300260468`*^9, 
   3.7507774336695113`*^9}},ExpressionUUID->"47ed7f3a-7f9b-46a7-8968-\
88fcf4671b34"],

Cell["\<\



Test frame to check if picture is as desired:\
\>", "Text",
 CellChangeTimes->{{3.513719827977401*^9, 3.513719828328863*^9}, {
  3.513721546802888*^9, 3.5137215495946417`*^9}, {3.513723809332707*^9, 
  3.5137238278556557`*^9}},ExpressionUUID->"d2858ae8-92b2-4b03-8cd5-\
495812ce14d8"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"tval", "=", 
   RowBox[{"1.5", "tref"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"pic", "=", 
  RowBox[{"ParametricPlot", "[", 
   RowBox[{
    RowBox[{"map", "[", 
     RowBox[{
      RowBox[{"R", " ", 
       RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ",", " ", 
      RowBox[{"R", " ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}]}], ",", " ", "tval"}], "]"}], 
    ",", " ", 
    RowBox[{"{", 
     RowBox[{"R", ",", " ", "a", ",", " ", "b"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"\[Theta]", ",", " ", "0", ",", " ", 
      RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"MeshStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"None", ",", 
       RowBox[{"{", 
        RowBox[{"Thick", ",", "Black"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"PlotPoints", "\[Rule]", "ppts"}], ",", 
    RowBox[{"BoundaryStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Thick", ",", "Black"}], "}"}]}], ",", 
    RowBox[{"ColorFunction", "\[Rule]", 
     RowBox[{"Function", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", "y", ",", "r", ",", "t"}], "}"}], ",", 
       RowBox[{"Hue", "[", 
        RowBox[{"t", "/", 
         RowBox[{"(", 
          RowBox[{"2", "Pi"}], ")"}]}], "]"}]}], "]"}]}], ",", 
    RowBox[{"ColorFunctionScaling", "\[Rule]", "False"}], ",", 
    "\[IndentingNewLine]", " ", 
    RowBox[{"Axes", " ", "\[Rule]", " ", "False"}], ",", " ", 
    RowBox[{"Frame", " ", "\[Rule]", " ", "False"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Export", "[", 
    RowBox[{"\"\<GenVort.png\>\"", ",", "pic"}], "]"}], "*)"}]}]}], "Input",
 CellChangeTimes->{{3.513721957657938*^9, 3.513721977708723*^9}, 
   3.513722546915081*^9, {3.513722605590228*^9, 3.5137226503811207`*^9}, {
   3.5137227019755573`*^9, 3.513722730591302*^9}, {3.513722854902466*^9, 
   3.513722866115307*^9}, {3.513729495500145*^9, 3.513729520521139*^9}, {
   3.7507774095087633`*^9, 3.7507774132896404`*^9}, {3.7507835605730457`*^9, 
   3.7507835611488576`*^9}, 
   3.750783617836749*^9},ExpressionUUID->"d5609ada-9ee5-4307-a197-\
4f47579d21c4"],

Cell["\<\


WARNING, BE PREPARED TO WAIT...
The following command takes about 15 minutes to finish.\
\>", "Text",
 CellChangeTimes->{{3.507321234982059*^9, 3.507321265574929*^9}, {
  3.513723831498081*^9, 
  3.51372383175185*^9}},ExpressionUUID->"64772259-42f9-4a26-a4e1-\
c29bf1298fef"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dt", "=", 
   RowBox[{"fac", "*", ".02", " ", "tref"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"frames", "=", 
   RowBox[{"Table", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"map", "[", 
        RowBox[{
         RowBox[{"R", " ", 
          RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ",", " ", 
         RowBox[{"R", " ", 
          RowBox[{"Sin", "[", "\[Theta]", "]"}]}], ",", " ", "tval"}], "]"}], 
       ",", " ", 
       RowBox[{"{", 
        RowBox[{"R", ",", " ", "a", ",", " ", "b"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"\[Theta]", ",", " ", "0", ",", " ", 
         RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"MeshStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"None", ",", 
          RowBox[{"{", 
           RowBox[{"Thick", ",", "Black"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "ppts"}], ",", 
       RowBox[{"BoundaryStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Thick", ",", "Black"}], "}"}]}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", 
        RowBox[{"Function", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"x", ",", "y", ",", "r", ",", "t"}], "}"}], ",", 
          RowBox[{"Hue", "[", 
           RowBox[{"t", "/", 
            RowBox[{"(", 
             RowBox[{"2", "Pi"}], ")"}]}], "]"}]}], "]"}]}], ",", 
       RowBox[{"ColorFunctionScaling", "\[Rule]", "False"}], ",", 
       "\[IndentingNewLine]", " ", 
       RowBox[{"Axes", " ", "\[Rule]", " ", "False"}], ",", " ", 
       RowBox[{"Frame", " ", "\[Rule]", " ", "False"}]}], "]"}], 
     "\[IndentingNewLine]", ",", 
     RowBox[{"{", 
      RowBox[{"tval", ",", "0", ",", 
       RowBox[{
        RowBox[{"2", "tref"}], "-", "dt"}], ",", "dt"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{"\"\<GeneralizedVortexRing.gif\>\"", ",", "frames"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.507314301918539*^9, 3.5073143317547493`*^9}, {
   3.5073145714490833`*^9, 3.507314583651642*^9}, {3.507315029792416*^9, 
   3.5073150345032187`*^9}, 3.513722754472508*^9, {3.513722847053896*^9, 
   3.513722871771195*^9}, 3.7507835694772*^9, 
   3.7507836221813765`*^9},ExpressionUUID->"74e5f34c-9a37-43c6-963c-\
ce54b9c04771"],

Cell["\<\



The following exports single frames of the animation.
To make an animated gif from the exported frames, execute the following on a \
Linux Workstation:

convert -verbose -delay 30 -loop 0 -density 100 gvr*.gif \
GeneralizedVortexRingSmall.gif

This command is currently commented out because we don\[CloseCurlyQuote]t \
currently need single frames.\
\>", "Text",
 CellChangeTimes->{{3.5137192941575108`*^9, 3.513719356031639*^9}, {
   3.513719434302765*^9, 3.513719463971859*^9}, {3.513719853192477*^9, 
   3.513719859608273*^9}, 3.513719960447527*^9, {3.513720035538024*^9, 
   3.513720045053907*^9}, {3.750783686107543*^9, 
   3.750783707412072*^9}},ExpressionUUID->"c4646a31-7eaa-4954-8aa3-\
2dcdfe1f8298"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"nfrms", "=", "40"}], ";", "\[IndentingNewLine]", 
   RowBox[{"inc", "=", 
    RowBox[{"Max", "[", 
     RowBox[{"2", ",", 
      RowBox[{"Round", "[", 
       FractionBox[
        RowBox[{"Length", "[", "frames", "]"}], "nfrms"], "]"}]}], "]"}]}], 
   ";", "\[IndentingNewLine]", 
   RowBox[{"Do", "[", 
    RowBox[{
     RowBox[{"Export", "[", 
      RowBox[{
       RowBox[{"\"\<gvr\>\"", "<>", 
        RowBox[{"IntegerString", "[", 
         RowBox[{"i", ",", "10", ",", "3"}], "]"}], "<>", "\"\<.gif\>\""}], 
       ",", 
       RowBox[{"frames", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "frames", "]"}], ",", "inc"}], "}"}]}], "]"}]}],
   "*)"}]], "Input",
 CellChangeTimes->{{3.513717331707492*^9, 3.513717364299511*^9}, {
   3.513717396693275*^9, 3.513717485036697*^9}, {3.513717700717195*^9, 
   3.5137177814581547`*^9}, {3.513717818626543*^9, 3.5137178340259247`*^9}, {
   3.513719094012022*^9, 3.5137190976502132`*^9}, {3.513719233472376*^9, 
   3.513719237932922*^9}, {3.513719868476447*^9, 3.5137198685458508`*^9}, 
   3.5137199633698797`*^9, {3.513721456083309*^9, 3.513721460516333*^9}, {
   3.7507775577515507`*^9, 3.7507775609755216`*^9}, {3.750783713315187*^9, 
   3.7507837232940173`*^9}},ExpressionUUID->"9848da6a-cd76-4627-8318-\
3b3471c1b418"],

Cell["\<\


Here is a hint of some things that can be done to alter the appearance\
\>", "Text",
 CellChangeTimes->{{3.50731666840167*^9, 
  3.507316679544436*^9}},ExpressionUUID->"aff5e7f8-efda-4c94-b4af-\
f8d0b05e7362"],

Cell["\<\


WARNING, BE PREPARED TO WAIT...
The following command takes about five minutes to finish.\
\>", "Text",
 CellChangeTimes->{{3.507321234982059*^9, 
  3.507321265574929*^9}},ExpressionUUID->"57696a2d-1ee5-4eb8-8042-\
08607721c6ab"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"mesh1", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"X", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Thickness", "[", "0.005", "]"}], ",", "White", ",", 
         RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X", ",", 
       RowBox[{"-", "Xval"}], ",", "Xval", ",", 
       RowBox[{"Xval", "/", "6"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"mesh2", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"X", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Thickness", "[", "0.005", "]"}], ",", "White", ",", 
          RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"X", ",", 
        RowBox[{"-", "Xval"}], ",", "Xval", ",", 
        RowBox[{"Xval", "/", "6"}]}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Xval", "=", 
   RowBox[{"1.2", "b"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dt", "=", 
   RowBox[{"fac", "*", " ", "0.02", " ", "tref"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"frames", "=", 
   RowBox[{"Table", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"map", "[", 
        RowBox[{"X1", ",", "X2", ",", "tval"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"X1", ",", 
         RowBox[{"-", "Xval"}], ",", "Xval"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"X2", ",", 
         RowBox[{"-", "Xval"}], ",", "Xval"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{
          RowBox[{"Opacity", "[", "0.999", "]"}], ",", "Blue"}], "]"}]}], ",",
        "\[IndentingNewLine]", 
       RowBox[{"Mesh", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"mesh1", ",", "mesh2"}], "}"}]}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "ppts"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Axes", "\[Rule]", "False"}], ",", 
       RowBox[{"Frame", "\[Rule]", "False"}]}], "]"}], "\[IndentingNewLine]", 
     ",", 
     RowBox[{"{", 
      RowBox[{"tval", ",", "0", ",", 
       RowBox[{
        RowBox[{"2", "tref"}], "-", "dt"}], ",", "dt"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"frames", "[", 
  RowBox[{"[", "5", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{"\"\<GeneralizedVortexSquareBlue.gif\>\"", ",", "frames"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.5073208204922857`*^9, 3.507320845740499*^9}, {
  3.7507835780684576`*^9, 
  3.750783581356406*^9}},ExpressionUUID->"060cf0fe-5f0f-4811-83ba-\
556b997add33"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"mesh1", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"X", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Thickness", "[", "0.005", "]"}], ",", "White", ",", 
         RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X", ",", 
       RowBox[{"-", "Xval"}], ",", "Xval", ",", 
       RowBox[{"Xval", "/", "10"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mesh2", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"X", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Thickness", "[", "0.005", "]"}], ",", "White", ",", 
         RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X", ",", 
       RowBox[{"-", "Xval"}], ",", "Xval", ",", 
       RowBox[{"Xval", "/", "10"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ParametricPlot", "[", 
  RowBox[{
   RowBox[{"map", "[", 
    RowBox[{"X1", ",", "X2", ",", ".5"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"X1", ",", 
     RowBox[{"-", "Xval"}], ",", "Xval"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"X2", ",", 
     RowBox[{"-", "Xval"}], ",", "Xval"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"MeshFunctions", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"#3", "&"}], ",", 
      RowBox[{"#4", " ", "&"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"ColorFunction", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"X1", ",", "X2", ",", "x1", ",", "x2"}], "}"}], ",", 
      RowBox[{
       RowBox[{"rdum", "=", 
        FractionBox[
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{
            SuperscriptBox["X1", "2"], "+", 
            SuperscriptBox["X2", "2"]}], "]"}], "-", "a"}], 
         RowBox[{"b", "-", "a"}]]}], ";", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"0", "<", "rdum", "<", "1"}], ",", 
         RowBox[{"Hue", "[", "rdum", "]"}], ",", "Black"}], "]"}]}]}], 
     "]"}]}], ",", 
   RowBox[{"ColorFunctionScaling", "\[Rule]", "False"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Mesh", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"mesh1", ",", "mesh2"}], "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"Axes", "\[Rule]", "False"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.507316790545154*^9, 3.507316792664751*^9}, {
  3.50731684434697*^9, 3.5073170376007547`*^9}, {3.5073170890440598`*^9, 
  3.507317123399929*^9}, {3.5073172382348223`*^9, 3.5073172608394747`*^9}, {
  3.507317310591021*^9, 3.507317442285798*^9}, {3.507317813253956*^9, 
  3.507317848744272*^9}, {3.5073178952548323`*^9, 3.507318023550997*^9}, {
  3.507318131045865*^9, 3.507318219246038*^9}, {3.50731832897394*^9, 
  3.507318494795534*^9}},ExpressionUUID->"cc7730c0-3e09-4519-bee2-\
1fc702bf6ae7"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"strain", "[", "Rbar_", "]"}], ":=", 
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"(", 
     RowBox[{"Rbar", "+", 
      FractionBox["1", 
       RowBox[{
        RowBox[{"b", "/", "c"}], "-", "1"}]]}], ")"}], 
    RowBox[{
     RowBox[{"\[Eta]", "'"}], "[", "Rbar", "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"peakstrain", "=", 
  RowBox[{"Abs", "[", 
   RowBox[{
    RowBox[{"N", "[", 
     RowBox[{"Minimize", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"strain", "[", "Rbar", "]"}], ",", 
         RowBox[{
          RowBox[{"-", "1"}], "<", "Rbar", "<", "1"}]}], "}"}], ",", "Rbar"}],
       "]"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"intensity", "[", "Rbar_", "]"}], ":=", 
  RowBox[{"Evaluate", "[", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "1"}], "<", "Rbar", "<", "1"}], ",", 
     FractionBox[
      RowBox[{"strain", "[", "Rbar", "]"}], "peakstrain"], ",", "0"}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"intensity", "[", "Rbar", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"Rbar", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5073190165254183`*^9, 3.507319089840473*^9}, {
  3.507319148259018*^9, 3.507319158992445*^9}, {3.5073191932907267`*^9, 
  3.5073194040126333`*^9}, {3.5073195705749283`*^9, 3.507319614836626*^9}, {
  3.750783830132914*^9, 3.750783867056257*^9}, {3.7507838977384796`*^9, 
  3.750783904394351*^9}},ExpressionUUID->"68b441c8-64e1-498f-bd69-\
0dcd0bde0a65"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Abs", "[", 
    RowBox[{"intensity", "[", 
     FractionBox[
      RowBox[{"x", "-", "c"}], 
      RowBox[{"b", "-", "a"}]], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{
      RowBox[{"-", "c"}], "/", 
      RowBox[{"(", 
       RowBox[{"b", "-", "a"}], ")"}]}], ",", 
     RowBox[{"2", "b"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5073200469227257`*^9, 
  3.507320080069871*^9}},ExpressionUUID->"0fe34662-e44b-43ac-a898-\
04397e320242"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"mesh1", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"X", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Thickness", "[", "0.005", "]"}], ",", "White", ",", 
         RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X", ",", 
       RowBox[{"-", "Xval"}], ",", "Xval", ",", 
       RowBox[{"Xval", "/", "8"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mesh2", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"X", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Thickness", "[", "0.005", "]"}], ",", "White", ",", 
         RowBox[{"Opacity", "[", "1", "]"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X", ",", 
       RowBox[{"-", "Xval"}], ",", "Xval", ",", 
       RowBox[{"Xval", "/", "8"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ParametricPlot", "[", 
  RowBox[{
   RowBox[{"map", "[", 
    RowBox[{"X1", ",", "X2", ",", ".2"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"X1", ",", 
     RowBox[{"-", "Xval"}], ",", "Xval"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"X2", ",", 
     RowBox[{"-", "Xval"}], ",", "Xval"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"MeshFunctions", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"#3", "&"}], ",", 
      RowBox[{"#4", " ", "&"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"ColorFunction", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"X1", ",", "X2", ",", "x1", ",", "x2"}], "}"}], ",", 
      RowBox[{
       RowBox[{"rdum", "=", 
        FractionBox[
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{
            SuperscriptBox["X1", "2"], "+", 
            SuperscriptBox["X2", "2"]}], "]"}], "-", "c"}], 
         FractionBox[
          RowBox[{"b", "-", "a"}], "2"]]}], ";", 
       RowBox[{"Hue", "[", 
        RowBox[{"Abs", "[", 
         RowBox[{"intensity", "[", "rdum", "]"}], "]"}], "]"}]}]}], "]"}]}], 
   ",", 
   RowBox[{"ColorFunctionScaling", "\[Rule]", "False"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Mesh", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"mesh1", ",", "mesh2"}], "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"Axes", "\[Rule]", "False"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.507320178531879*^9, 3.50732020404986*^9}, {
  3.507320341511574*^9, 3.5073203570085907`*^9}, {3.507320393882468*^9, 
  3.507320416040805*^9}, {3.50732046033797*^9, 
  3.507320524858062*^9}},ExpressionUUID->"a82ac726-d78c-47fb-8280-\
5975d0f5ad40"],

Cell["\<\



Enjoy playing around with this stuff!

REFERENCES:
[1] Kamojjala, K.C., R. Brannon, A. Sadeghirad, and J. Guilkey (2015) \
Verification tests in solid mechanics, Engineering with
Computers, v. 2, pp. 193-213
[2] Sadeghirad, A., R. M. Brannon, and J. Burghardt (2011) A convected \
particle domain interpolation technique to extend
applicability of the material point method for problems involving massive \
deformations, Int. J. Numer. Meth. in Engr.,
86(12), pp. 1435-1456.\
\>", "Text",
 CellChangeTimes->{{3.7507842556747684`*^9, 3.75078426359377*^9}, {
  3.750784615997304*^9, 
  3.7507846745808983`*^9}},ExpressionUUID->"475b915a-2551-41f4-a87e-\
e2df58074e25"]
}, Open  ]]
},
WindowSize->{1069, 1001},
WindowMargins->{{279, Automatic}, {-35, Automatic}},
PrintingCopies->1,
PrintingPageRange->{32000, 32000},
PrintingOptions->{"Magnification"->1.,
"PaperOrientation"->"Portrait",
"PaperSize"->{612, 792}},
ShowSelection->True,
FrontEndVersion->"11.2 for Microsoft Windows (64-bit) (September 10, 2017)",
StyleDefinitions->FrontEnd`FileName[{"Creative"}, "NaturalColor.nb", 
  CharacterEncoding -> "UTF-8"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 401004, 6712, 3438, "Text",ExpressionUUID->"cb8ae8be-6fb7-4b4d-b82c-0a0e388d6742"],
Cell[CellGroupData[{
Cell[401574, 6736, 172, 3, 75, "Section",ExpressionUUID->"d94ca194-aa74-49b8-b2e6-9a441ffd3418"],
Cell[401749, 6741, 444, 15, 60, "Text",ExpressionUUID->"cad12c40-0a34-452c-b18e-649329fac7cf"],
Cell[402196, 6758, 6507, 211, 464, "Text",ExpressionUUID->"4ce621cb-a85a-4600-b721-7d943fcc4255"]
}, Open  ]],
Cell[CellGroupData[{
Cell[408740, 6974, 216, 4, 75, "Section",ExpressionUUID->"126a11ac-a8d9-4b04-a844-8fc3b369355b"],
Cell[408959, 6980, 2351, 74, 138, "Text",ExpressionUUID->"be24ca1a-e41d-4249-862f-cd3939858b07"],
Cell[411313, 7056, 14134, 456, 1111, "Text",ExpressionUUID->"1cb431de-dbef-4728-ad45-4379d4be47ae"],
Cell[425450, 7514, 4689, 147, 279, "Text",ExpressionUUID->"a1ba11b3-5ff2-4b6c-b1f0-daa2e452e1ad"],
Cell[430142, 7663, 6163, 199, 198, "Text",ExpressionUUID->"322ef6eb-7754-4ce1-8da6-35431712f05c"],
Cell[436308, 7864, 726, 20, 40, "Output",ExpressionUUID->"93cc5100-c29c-479a-8de6-3120a586da1b"],
Cell[437037, 7886, 6744, 202, 409, "Text",ExpressionUUID->"85ca4671-663f-4f3e-9ece-8c7435ab759b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[443818, 8093, 164, 3, 75, "Section",ExpressionUUID->"cb233d0a-26c9-47da-b0ae-7ae4296427bc"],
Cell[443985, 8098, 7347, 237, 274, "Text",ExpressionUUID->"29f18a2b-0007-49cf-a95d-5caa75b1c845"],
Cell[451335, 8337, 4029, 104, 84, "Text",ExpressionUUID->"ec9e21c5-ea22-4bfa-9b6b-dcfbc9686a0d"],
Cell[455367, 8443, 4904, 158, 163, "Text",ExpressionUUID->"1413783c-5184-4b80-a465-12693d1a4cf2"],
Cell[460274, 8603, 5043, 159, 223, "Text",ExpressionUUID->"5d3ce0e2-1682-49bd-bf1a-c9bea912ad01"]
}, Open  ]],
Cell[CellGroupData[{
Cell[465354, 8767, 165, 3, 75, "Section",ExpressionUUID->"6d194eca-5f7f-4735-a91c-b924df3d2a00"],
Cell[465522, 8772, 1535, 50, 147, "Text",ExpressionUUID->"7f85de26-a743-45e4-838e-87ea77de3e94"],
Cell[467060, 8824, 2699, 83, 107, "Text",ExpressionUUID->"24eb9f75-eb06-4d3e-96ec-7b2237f9458e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[469796, 8912, 156, 3, 75, "Section",ExpressionUUID->"3b5cd0a9-7aa3-498d-bb47-312b3ea62cae"],
Cell[469955, 8917, 5505, 163, 522, "Text",ExpressionUUID->"0b78b761-4063-42d1-8901-1fb0adb5be2a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[475497, 9085, 216, 4, 75, "Section",ExpressionUUID->"3ecbd097-7059-469b-8f60-b2248560f744"],
Cell[475716, 9091, 1505, 37, 130, "Text",ExpressionUUID->"fd2cf5c2-a341-4c8c-ac5e-ce6377e40f4c"],
Cell[477224, 9130, 206, 4, 40, "Input",ExpressionUUID->"404fec1d-d741-4eb7-abb9-98211f86182d"],
Cell[477433, 9136, 253, 5, 31, "Text",ExpressionUUID->"ced80c35-1eeb-4e4f-8f0e-1e7a6365ff53"],
Cell[477689, 9143, 223, 5, 60, "Input",ExpressionUUID->"ee78720f-2005-498c-afcf-45120f26f8af"],
Cell[477915, 9150, 182, 3, 31, "Text",ExpressionUUID->"5a467ce7-4214-4234-b533-842484395f68"],
Cell[478100, 9155, 529, 14, 105, "Input",ExpressionUUID->"05a2c4bd-d489-46e6-849b-0eb4f554bb5d"],
Cell[478632, 9171, 538, 15, 105, "Input",ExpressionUUID->"6d70bffb-f1c2-4fc9-990b-f82f2cdbc8a4"],
Cell[479173, 9188, 260, 7, 40, "Input",ExpressionUUID->"175df049-18fc-4d10-ac1c-b1f065d00cc6"],
Cell[479436, 9197, 3667, 118, 442, "Text",ExpressionUUID->"7569dd7b-26f7-4086-9a26-46dc9d728e4d"],
Cell[483106, 9317, 243, 6, 31, "Text",ExpressionUUID->"88f0fb83-a95d-46ed-b0b1-fb5c7bfb4dd5"],
Cell[483352, 9325, 786, 18, 60, "Input",ExpressionUUID->"c87c440e-09fb-4ddf-ae65-c45ed7827bf7"],
Cell[484141, 9345, 345, 8, 51, "Text",ExpressionUUID->"e693583b-d3e4-4f93-933a-f206ad230a69"],
Cell[484489, 9355, 1829, 51, 207, "Input",ExpressionUUID->"4a4168ee-08a7-4297-911b-f13144013c98"],
Cell[486321, 9408, 236, 6, 31, "Text",ExpressionUUID->"427dd458-6915-4754-9498-9189adc38be9"],
Cell[486560, 9416, 288, 4, 31, "Text",ExpressionUUID->"53d71845-bc4b-4f94-bd3f-4d7b55bdbd02"],
Cell[486851, 9422, 817, 24, 105, "Input",ExpressionUUID->"7b51acee-cb88-4c51-9638-a06bf6c3a7ed"],
Cell[487671, 9448, 236, 6, 31, "Text",ExpressionUUID->"64e1da30-6c5b-48bc-a6ba-a3cf1f9cba80"],
Cell[487910, 9456, 265, 7, 51, "Text",ExpressionUUID->"c183c949-891c-4ab3-9d0d-a818c17d4c5e"],
Cell[488178, 9465, 550, 14, 96, "Input",ExpressionUUID->"76f4bfc8-57e9-4dd6-9c67-c19fc3a499e8"],
Cell[488731, 9481, 850, 17, 120, "Text",ExpressionUUID->"162060f2-fc2a-4289-ab90-33487d5a10ec"],
Cell[489584, 9500, 2028, 54, 202, "Input",ExpressionUUID->"0fd082ed-8a75-455e-945b-75c714a0423b"],
Cell[491615, 9556, 246, 6, 31, "Text",ExpressionUUID->"0a1a8231-7cf6-4ae0-a224-aea0d442caf1"],
Cell[491864, 9564, 261, 7, 63, "Input",ExpressionUUID->"8fd56f0f-d9dd-40e3-86b0-aa49f285b5be"],
Cell[492128, 9573, 2838, 84, 167, "Text",ExpressionUUID->"bb0b9893-b222-4536-b4b4-2de22663a41f"],
Cell[494969, 9659, 1992, 54, 65, "Input",ExpressionUUID->"9a740772-cfb0-4523-bda5-f8967aab7b75"],
Cell[496964, 9715, 1748, 49, 65, "Input",ExpressionUUID->"5ae51c84-5d15-496e-8960-b9c4a3e8fd97"],
Cell[498715, 9766, 217, 8, 91, "Text",ExpressionUUID->"bfb57d10-f866-4bab-a63b-9d37c2612302"],
Cell[498935, 9776, 507, 11, 60, "Input",ExpressionUUID->"98048b75-7043-4ad6-8d3d-3458d9a761cb"],
Cell[499445, 9789, 403, 8, 31, "Text",ExpressionUUID->"1ad93a5f-87b6-4509-b608-56f67b0edf1e"],
Cell[499851, 9799, 235, 5, 40, "Input",ExpressionUUID->"b03acf52-96e2-4709-9751-7879879f316c"],
Cell[500089, 9806, 543, 15, 73, "Input",ExpressionUUID->"fb4ec805-c4e3-4452-8767-d532a7f97175"],
Cell[500635, 9823, 546, 12, 60, "Input",ExpressionUUID->"69e304e6-afc1-4564-860e-54f784979ff7"],
Cell[501184, 9837, 320, 8, 40, "Input",ExpressionUUID->"4df0239b-ad2a-4192-a4d4-05ba3207e422"]
}, Open  ]],
Cell[CellGroupData[{
Cell[501541, 9850, 223, 5, 75, "Section",ExpressionUUID->"76cfb5a2-86af-4880-b056-6e129d9bd2b5"],
Cell[501767, 9857, 328, 7, 51, "Text",ExpressionUUID->"699833d8-ceec-421f-9304-99806aea8d2d"],
Cell[502098, 9866, 255, 7, 44, "Input",ExpressionUUID->"a96eb020-8a7e-4f54-b122-bbe62b84e6c8"],
Cell[502356, 9875, 282, 6, 31, "Text",ExpressionUUID->"b36d3d0f-ca78-463b-b633-99f9cc7dbd8d"],
Cell[502641, 9883, 297, 5, 40, "Input",ExpressionUUID->"180ae742-31b0-455b-8ff7-4fd578644aab"],
Cell[502941, 9890, 638, 12, 111, "Text",ExpressionUUID->"4bffe12b-59b4-4326-9b72-22d7e8d8806d"],
Cell[503582, 9904, 386, 11, 40, "Input",ExpressionUUID->"b2a94471-9843-444b-b772-5e84f78d0185"],
Cell[503971, 9917, 237, 6, 31, "Text",ExpressionUUID->"ea293819-5c48-4e4e-8cf2-9a1ebac7564a"],
Cell[504211, 9925, 239, 6, 43, "Input",ExpressionUUID->"98506859-0a72-4e5e-bf18-1d777fcd4de8"],
Cell[504453, 9933, 355, 8, 43, "Input",ExpressionUUID->"abcc3cb1-a08d-4214-aec1-6a3c6914dd6d"],
Cell[504811, 9943, 282, 7, 43, "Input",ExpressionUUID->"84822f05-cf3f-423d-92b5-a90fcabae486"],
Cell[505096, 9952, 294, 7, 43, "Input",ExpressionUUID->"de3557b9-df42-440a-9e0e-d45bf9c62a9b"],
Cell[505393, 9961, 275, 6, 31, "Text",ExpressionUUID->"fafda931-bcc5-4fb7-bae1-438ee0f34bcb"],
Cell[505671, 9969, 1375, 35, 110, "Input",ExpressionUUID->"51c5ff2e-43a3-4fe6-aa8e-3c04c44ba9de"],
Cell[507049, 10006, 2134, 73, 173, "Text",ExpressionUUID->"3b2cbd70-56e5-4270-8a96-433c76d89399"],
Cell[509186, 10081, 503, 15, 60, "Input",ExpressionUUID->"4225244e-9cdc-4004-aaca-5f6b44d8c3ae"],
Cell[509692, 10098, 337, 7, 51, "Text",ExpressionUUID->"7d17ebb7-99bc-4bca-8616-c2c50a9d7911"],
Cell[510032, 10107, 612, 17, 108, "Input",ExpressionUUID->"5a8ab21d-8036-419c-97be-81ac42444e4c"],
Cell[510647, 10126, 514, 14, 108, "Input",ExpressionUUID->"344c9108-2069-408a-81a8-9f8127a0087b"],
Cell[511164, 10142, 255, 6, 31, "Text",ExpressionUUID->"f8862ef6-5ffc-43a3-9fe2-dffe1431c939"],
Cell[511422, 10150, 456, 11, 60, "Input",ExpressionUUID->"10b02881-d52f-4ab1-85d3-f8e38cbaef6c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[511915, 10166, 159, 3, 75, "Section",ExpressionUUID->"3a0905cd-0362-49eb-90e0-2b781155b023"],
Cell[512077, 10171, 230, 5, 40, "Input",ExpressionUUID->"7e3dca07-f4d5-488e-b939-20826c4758c7"],
Cell[512310, 10178, 280, 6, 31, "Text",ExpressionUUID->"466e43e4-5f89-4835-a8b3-25228bf69ef8"],
Cell[512593, 10186, 228, 5, 40, "Input",ExpressionUUID->"79785c14-30a1-4c6d-9e0c-2b89f4582ff5"],
Cell[512824, 10193, 393, 11, 60, "Input",ExpressionUUID->"002593fa-38d8-4f0f-82d3-681229cc29ee"],
Cell[513220, 10206, 231, 5, 40, "Input",ExpressionUUID->"19d63f19-f207-4565-977f-b82d5b0dd2ee"],
Cell[513454, 10213, 1505, 45, 207, "Input",ExpressionUUID->"46bbccbf-92ec-405c-843e-381dd38d72d6"],
Cell[514962, 10260, 677, 19, 86, "Input",ExpressionUUID->"cd4f3703-be87-48e6-936f-b62765bf304c"],
Cell[515642, 10281, 531, 16, 105, "Input",ExpressionUUID->"08f78e6f-101d-4b0a-aa8c-5936ff1882f7"],
Cell[516176, 10299, 533, 15, 60, "Text",ExpressionUUID->"ba2d19b0-979b-4cf4-8429-cade13138633"],
Cell[516712, 10316, 196, 5, 40, "Input",ExpressionUUID->"63c30cad-1cc8-472b-a900-f3a3476d6e5b"],
Cell[516911, 10323, 1176, 34, 115, "Input",ExpressionUUID->"861a6770-4f34-46e5-837b-74d436522471"],
Cell[518090, 10359, 385, 11, 40, "Input",ExpressionUUID->"85fdecab-2ada-453d-b9fe-cf600a60da72"],
Cell[518478, 10372, 1571, 42, 174, "Input",ExpressionUUID->"93c0cdf0-6649-471d-8699-ce62b18d0993"],
Cell[520052, 10416, 796, 20, 191, "Text",ExpressionUUID->"4e3ea826-e408-4464-b64c-bc76d892863b"],
Cell[520851, 10438, 1439, 35, 107, "Input",ExpressionUUID->"47ed7f3a-7f9b-46a7-8968-88fcf4671b34"],
Cell[522293, 10475, 297, 9, 91, "Text",ExpressionUUID->"d2858ae8-92b2-4b03-8cd5-495812ce14d8"],
Cell[522593, 10486, 2159, 53, 136, "Input",ExpressionUUID->"d5609ada-9ee5-4307-a197-4f47579d21c4"],
Cell[524755, 10541, 287, 9, 91, "Text",ExpressionUUID->"64772259-42f9-4a26-a4e1-c29bf1298fef"],
Cell[525045, 10552, 2394, 58, 174, "Input",ExpressionUUID->"74e5f34c-9a37-43c6-963c-ce54b9c04771"],
Cell[527442, 10612, 723, 19, 191, "Text",ExpressionUUID->"c4646a31-7eaa-4954-8aa3-2dcdfe1f8298"],
Cell[528168, 10633, 1422, 33, 91, "Input",ExpressionUUID->"9848da6a-cd76-4627-8318-3b3471c1b418"],
Cell[529593, 10668, 221, 7, 71, "Text",ExpressionUUID->"aff5e7f8-efda-4c94-b4af-f8d0b05e7362"],
Cell[529817, 10677, 241, 8, 91, "Text",ExpressionUUID->"57696a2d-1ee5-4eb8-8042-08607721c6ab"],
Cell[530061, 10687, 2816, 79, 269, "Input",ExpressionUUID->"060cf0fe-5f0f-4811-83ba-556b997add33"],
Cell[532880, 10768, 2928, 78, 233, "Input",ExpressionUUID->"cc7730c0-3e09-4519-bee2-1fc702bf6ae7"],
Cell[535811, 10848, 1678, 48, 157, "Input",ExpressionUUID->"68b441c8-64e1-498f-bd69-0dcd0bde0a65"],
Cell[537492, 10898, 538, 17, 61, "Input",ExpressionUUID->"0fe34662-e44b-43ac-a898-04397e320242"],
Cell[538033, 10917, 2663, 75, 251, "Input",ExpressionUUID->"a82ac726-d78c-47fb-8280-5975d0f5ad40"],
Cell[540699, 10994, 679, 19, 231, "Text",ExpressionUUID->"475b915a-2551-41f4-a87e-e2df58074e25"]
}, Open  ]]
}
]
*)

